=== modified file 'client/Makefile.am'
--- client/Makefile.am	2008-08-10 20:10:21 +0000
+++ client/Makefile.am	2008-08-12 01:38:38 +0000
@@ -38,6 +38,7 @@
 drizzle_SOURCES =		drizzle.cc readline.cc completion_hash.cc
 drizzle_LDADD =			$(READLINE_LIBS) $(TERMCAP_LIBS) \
 				$(LDADD) $(CXXLDFLAGS)
+drizzle_CXXFLAGS =		${AM_CXXFLAGS} -fexceptions
 drizzleadmin_SOURCES =		drizzleadmin.cc
 
 drizzlebinlog_SOURCES =     drizzlebinlog.cc \
@@ -52,11 +53,10 @@
 drizzleimport_SOURCES=		drizzleimport.cc
 
 mysqlslap_SOURCES=		mysqlslap.c
-mysqlslap_CFLAGS=		-DTHREAD -UUNDEF_THREADS_HACK
 
 drizzletest_SOURCES=		drizzletest.cc 
 drizzletest_LDADD =		${LDADD} $(PCRE_LIBS)
-drizzletest_CFLAGS = 		${AM_CPPFLAGS} $(PCRE_CFLAGS)
+drizzletest_CXXFLAGS = 		${AM_CXXFLAGS} $(PCRE_CFLAGS)
 
 DEFS =	-DDEFAULT_MYSQL_HOME="\"$(prefix)\"" \
 	-DDATADIR="\"$(localstatedir)\"" \

=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2008-08-11 17:33:54 +0000
+++ client/drizzle.cc	2008-08-11 21:00:58 +0000
@@ -1039,6 +1039,7 @@
                             "drizzle>> ", MYF(0));
   current_prompt= my_strdup(default_prompt, MYF(0));
   processed_prompt= new string();
+  processed_prompt->reserve(32);
 
   prompt_counter=0;
 
@@ -1120,6 +1121,8 @@
            INFO_INFO,0,0);
 
   glob_buffer= new string();
+  glob_buffer->reserve(512);
+  
   char * output_buff= (char *)malloc(512);
   memset(output_buff, '\0', 512);
 
@@ -1856,7 +1859,7 @@
     }
 #endif
         if (!*ml_comment && inchar == '\\' &&
-        !(drizzle.server_status & SERVER_STATUS_NO_BACKSLASH_ESCAPES))
+            !(*in_string && (drizzle.server_status & SERVER_STATUS_NO_BACKSLASH_ESCAPES)))
     {
       // Found possbile one character command like \c
 
@@ -2107,6 +2110,7 @@
 
   /* Converted buffer */
   string fixed_buffer;
+  fixed_buffer.reserve(512);
 
   /* find out how many lines we have and remove newlines */
   while (*ptr != '\0')
@@ -2966,6 +2970,8 @@
   DRIZZLE_FIELD   *field;
   bool          *num_flag;
   string separator;
+  
+  separator.reserve(256);
 
   num_flag=(bool*) my_malloc(sizeof(bool)*drizzle_num_fields(result),
                              MYF(MY_WME));

=== modified file 'configure.ac'
--- configure.ac	2008-08-11 17:33:54 +0000
+++ configure.ac	2008-08-12 02:14:14 +0000
@@ -60,6 +60,8 @@
 sinclude(m4/ac_cxx_header_stdcxx_98.m4)
 
 AM_GNU_GETTEXT([external])
+AM_GNU_GETTEXT_VERSION(0.17)
+
 
 AC_SUBST(MYSQL_NO_DASH_VERSION)
 AC_SUBST(MYSQL_BASE_VERSION)
@@ -253,8 +255,8 @@
 then
   case "$host_cpu" in
     *ppc* | *powerpc*)
-      CFLAGS="$CFLAGS -mno-fused-madd"
-      CXXFLAGS="$CXXFLAGS -mno-fused-madd"
+      AM_CFLAGS="$CFLAGS -mno-fused-madd"
+      AM_CXXFLAGS="$CXXFLAGS -mno-fused-madd"
     ;;
   esac
 fi
@@ -274,9 +276,7 @@
 then
   # Disable exceptions as they seams to create problems with gcc and threads.
   # drizzled doesn't use run-time-type-checking, so we disable it.
-  CXXFLAGS="$CXXFLAGS -fno-exceptions -fno-rtti"
-  AC_DEFINE([HAVE_EXPLICIT_TEMPLATE_INSTANTIATION],
-    [1], [Defined by configure. Use explicit template instantiation.])
+  AM_CXXFLAGS="${AM_CXXFLAGS} -fno-exceptions -fno-rtti"
 fi
 
 MYSQL_PROG_AR
@@ -287,6 +287,38 @@
 fi
 AC_SUBST(LD_VERSION_SCRIPT)
 
+#--------------------------------------------------------------------
+# Check for Google Proto Buffers
+#--------------------------------------------------------------------
+
+AC_LANG_PUSH([C++])
+AC_CHECK_HEADERS([google/protobuf/message.h])
+if test "x$ac_cv_header_google_protobuf_message_h" != "xyes"
+then
+  AC_MSG_ERROR([Couldn't find message.h. Try installing Google Protocol Buffer development packages])
+fi
+
+save_CFLAGS="$CFLAGS"
+save_LIBS="$LIBS"
+CFLAGS=""
+LIBS="-lprotobuf"
+
+AC_CACHE_CHECK([for Message in libprotobuf], ac_libprotobuf_works, [
+  AC_TRY_LINK([
+#include <google/protobuf/descriptor.pb.h>
+  ],[
+    google::protobuf::FileDescriptorProto testFdp;
+  ], ac_libprotobuf_works=yes, [
+        AC_ERROR([could not find Google's libprotobuf])
+  ])
+
+])
+
+PROTOBUF_LIBS="${LIBS}"
+AC_SUBST(PROTOBUF_LIBS)
+CFLAGS="$save_CFLAGS"
+LIBS="$save_LIBS"
+AC_LANG_POP()
 
 #--------------------------------------------------------------------
 # Check for libevent
@@ -431,6 +463,7 @@
 LIBS="$my_save_LIBS"
 AC_SUBST(READLINE_LIBS)
 
+
 #--------------------------------------------------------------------
 # Check for libpcre
 #--------------------------------------------------------------------
@@ -1056,6 +1089,16 @@
   tell tempnam vidattr \
   posix_fallocate backtrace backtrace_symbols backtrace_symbols_fd)
 
+AC_LANG_PUSH(C++)
+# Test whether madvise() is declared in C++ code -- it is not on some
+# systems, such as Solaris
+AC_CHECK_DECLS(madvise, [], [], [#if HAVE_SYS_MMAN_H
+#include <sys/types.h>
+#include <sys/mman.h>
+#endif])
+AC_LANG_POP()
+
+
 AM_CONDITIONAL(BUILD_THR_RWLOCK,[test "$ac_cv_func_rwlock_init" -a "$ac_cv_funn_pthread_rwlock_rdlock"])
 
 # Check that isinf() is available in math.h and can be used in both C and C++
@@ -1347,12 +1390,14 @@
   GCC_WARNINGS="${C99_SUPPORT_HACK} ${BASE_WARNINGS} ${GCC_PEDANTIC} ${W_UNREACHABLE} ${W_FAIL} ${GPROF_PROFILING} ${GPROF_COVERAGE}"
   GXX_WARNINGS="${BASE_WARNINGS} ${GXX_PEDANTIC} ${W_UNREACHABLE} ${W_FAIL} ${GPROF_PROFILING} ${GPROF_COVERAGE}"
 
-  CXXFLAGS="$CXXFLAGS ${GXX_WARNINGS}"
-  CFLAGS="$CFLAGS ${GCC_WARNINGS} "
+  AM_CXXFLAGS="${GXX_WARNINGS} ${AM_CXXFLAGS}"
+  AM_CFLAGS="${GCC_WARNINGS} ${AM_CFLAGS}"
 fi
 
 AC_SUBST([GLOBAL_CPPFLAGS],['-I$(top_srcdir) -I$(top_builddir)'])
 AC_SUBST([AM_CPPFLAGS],['${GLOBAL_CPPFLAGS}'])
+AC_SUBST([AM_CFLAGS])
+AC_SUBST([AM_CXXFLAGS])
 
 # Some usefull subst
 AC_SUBST(CC)
@@ -1386,6 +1431,6 @@
 AC_CONFIG_COMMANDS([default], , test -z "$CONFIG_HEADERS" || echo timestamp > stamp-h)
 
 # Ensure that table handlers gets all modifications to CFLAGS/CXXFLAGS
-AC_CONFIG_COMMANDS_POST(ac_configure_args="$ac_configure_args CFLAGS='$CFLAGS' CXXFLAGS='$CXXFLAGS'")
+AC_CONFIG_COMMANDS_POST(ac_configure_args="$ac_configure_args CFLAGS='$CFLAGS' CXXFLAGS='$CXXFLAGS' AM_CFLAGS='$AM_CFLAGS' AM_CXXFLAGS='$AM_CXXFLAGS'")
 
 AC_OUTPUT

=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2008-08-11 05:29:08 +0000
+++ drizzled/Makefile.am	2008-08-11 21:00:24 +0000
@@ -36,7 +36,7 @@
 bin_SCRIPTS = 	drizzledumpslow \
 		drizzled_safe 
 
-AM_CPPFLAGS = ${GLOBAL_CPPFLAGS} ${LIBEVENT_CPPFLAGS}
+AM_CPPFLAGS = ${GLOBAL_CPPFLAGS} ${LIBEVENT_CPPFLAGS} 
 
 DTRACE = @DTRACE@
 

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2008-08-11 04:55:59 +0000
+++ drizzled/drizzled.cc	2008-08-12 02:35:40 +0000
@@ -247,7 +247,7 @@
 bool opt_slow_log;
 ulong log_output_options;
 bool opt_log_queries_not_using_indexes= false;
-bool opt_error_log= IF_WIN(1,0);
+bool opt_error_log= 0;
 bool opt_skip_show_db= false;
 bool opt_character_set_client_handshake= 1;
 bool server_id_supplied = 0;
@@ -3911,7 +3911,7 @@
    "The number of seconds the server waits for activity on a connection before closing it.",
    (char**) &global_system_variables.net_wait_timeout,
    (char**) &max_system_variables.net_wait_timeout, 0, GET_ULONG,
-   REQUIRED_ARG, NET_WAIT_TIMEOUT, 1, IF_WIN(INT32_MAX/1000, LONG_TIMEOUT),
+   REQUIRED_ARG, NET_WAIT_TIMEOUT, 1, LONG_TIMEOUT,
    0, 1, 0},
   {0, 0, 0, 0, 0, 0, GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0}
 };
@@ -4307,7 +4307,7 @@
   global_system_variables.myisam_stats_method= MI_STATS_METHOD_NULLS_NOT_EQUAL;
 
   /* Variables that depends on compile options */
-  opt_error_log= IF_WIN(1,0);
+  opt_error_log= 0;
 #ifdef HAVE_BROKEN_REALPATH
   have_symlink=SHOW_OPTION_NO;
 #else

=== modified file 'drizzled/global.h'
--- drizzled/global.h	2008-08-05 17:09:26 +0000
+++ drizzled/global.h	2008-08-12 02:39:48 +0000
@@ -52,9 +52,6 @@
 
 #include "config.h"
 
-/* Make it easier to add conditionl code for windows */
-#define IF_WIN(A,B) (B)
-
 /*
   The macros below are borrowed from include/linux/compiler.h in the
   Linux kernel. Use them to indicate the likelyhood of the truthfulness
@@ -71,61 +68,6 @@
 #define likely(x)	__builtin_expect((x),1)
 #define unlikely(x)	__builtin_expect((x),0)
 
-
-/*
-  The macros below are useful in optimising places where it has been
-  discovered that cache misses stall the process and where a prefetch
-  of the cache line can improve matters. This is available in GCC 3.1.1
-  and later versions.
-  PREFETCH_READ says that addr is going to be used for reading and that
-  it is to be kept in caches if possible for a while
-  PREFETCH_WRITE also says that the item to be cached is likely to be
-  updated.
-  The *LOCALITY scripts are also available for experimentation purposes
-  mostly and should only be used if they are verified to improve matters.
-  For more input see GCC manual (available in GCC 3.1.1 and later)
-*/
-
-#if (__GNUC__ > 3) || (__GNUC__ == 3 && __GNUC_MINOR > 10)
-#define PREFETCH_READ(addr) __builtin_prefetch(addr, 0, 3)
-#define PREFETCH_WRITE(addr) \
-  __builtin_prefetch(addr, 1, 3)
-#define PREFETCH_READ_LOCALITY(addr, locality) \
-  __builtin_prefetch(addr, 0, locality)
-#define PREFETCH_WRITE_LOCALITY(addr, locality) \
-  __builtin_prefetch(addr, 1, locality)
-#else
-#define PREFETCH_READ(addr)
-#define PREFETCH_READ_LOCALITY(addr, locality)
-#define PREFETCH_WRITE(addr)
-#define PREFETCH_WRITE_LOCALITY(addr, locality)
-#endif
-
-/*
-  now let's figure out if inline functions are supported
-  autoconf defines 'inline' to be empty, if not
-*/
-#if defined(inline)
-#define HAVE_INLINE
-#endif
-/* helper macro for "instantiating" inline functions */
-#define STATIC_INLINE static inline
-
-/*
-  The following macros are used to control inlining a bit more than
-  usual. These macros are used to ensure that inlining always or
-  never occurs (independent of compilation mode).
-  For more input see GCC manual (available in GCC 3.1.1 and later)
-*/
-
-#if (__GNUC__ > 3) || (__GNUC__ == 3 && __GNUC_MINOR > 10)
-#define ALWAYS_INLINE __attribute__ ((always_inline))
-#define NEVER_INLINE __attribute__ ((noinline))
-#else
-#define ALWAYS_INLINE
-#define NEVER_INLINE
-#endif
-
 /*
  *   Disable __attribute__ for non GNU compilers, since we're using them
  *     only to either generate or suppress warnings.
@@ -152,15 +94,7 @@
 #include <sys/types.h>
 #endif
 
-#ifdef HAVE_THREADS_WITHOUT_SOCKETS
-/* MIT pthreads does not work with unix sockets */
-#undef HAVE_SYS_UN_H
-#endif
-
 #define __EXTENSIONS__ 1	/* We want some extension */
-#ifndef __STDC_EXT__
-#define __STDC_EXT__ 1          /* To get large file support on hpux */
-#endif
 
 /*
   Solaris 9 include file <sys/feature_tests.h> refers to X/Open document
@@ -200,20 +134,10 @@
 
 #define _REENTRANT	1	/* Some thread libraries require this */
 
-#if !defined(_THREAD_SAFE) && !defined(_AIX)
-#define _THREAD_SAFE            /* Required for OSF1 */
-#endif
-
 #include <pthread.h>		/* AIX must have this included first */
 
 #define _REENTRANT	1	/* Threads requires reentrant code */
 
-/* Go around some bugs in different OS and compilers */
-
-#if defined(HAVE_BROKEN_INLINE) && !defined(__cplusplus)
-#undef inline
-#define inline
-#endif
 
 /* gcc/egcs issues */
 

=== modified file 'mysys/my_bit.c'
--- mysys/my_bit.c	2008-07-30 05:33:20 +0000
+++ mysys/my_bit.c	2008-08-12 02:34:08 +0000
@@ -15,13 +15,6 @@
 
 #include "mysys_priv.h"
 
-#ifndef HAVE_INLINE
-/* the following will cause all inline functions to be instantiated */
-#define HAVE_INLINE
-#undef STATIC_INLINE
-#define STATIC_INLINE extern
-#endif
-
 #include <mysys/my_bit.h>
 
 const char _my_bits_nbits[256] = {

=== modified file 'plugin/crc32/Makefile.am'
--- plugin/crc32/Makefile.am	2008-07-27 23:12:07 +0000
+++ plugin/crc32/Makefile.am	2008-08-12 01:11:07 +0000
@@ -23,13 +23,10 @@
 EXTRA_LTLIBRARIES =	libcrc32udf.la
 pkgplugin_LTLIBRARIES =	@plugin_crc32_shared_target@
 libcrc32udf_la_LDFLAGS =	-module -rpath $(pkgplugindir) -lz
-libcrc32udf_la_CXXFLAGS=	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
-libcrc32udf_la_CFLAGS =	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
+libcrc32udf_la_CXXFLAGS=	$(AM_CXXFLAGS) -DMYSQL_DYNAMIC_PLUGIN
 libcrc32udf_la_SOURCES =	crc32udf.cc
 
 
 EXTRA_LIBRARIES =	libcrc32udf.a
 noinst_LIBRARIES =	@plugin_crc32_static_target@
-libcrc32udf_a_CXXFLAGS =	$(AM_CFLAGS)
-libcrc32udf_a_CFLAGS =	$(AM_CFLAGS)
 libcrc32udf_a_SOURCES=	$(libcrc32udf_la_SOURCES)

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2008-08-07 21:44:16 +0000
+++ po/POTFILES.in	2008-08-12 15:57:07 +0000
@@ -1,10 +1,11 @@
 # List of source files which contain translatable strings.
-client/drizzle.c
+client/drizzle.cc
 client/drizzleadmin.cc
 mysys/errors.c
 mysys/my_error.c
 mysys/my_getopt.c
 mysys/my_handler_errors.h
+drizzled/drizzled_error_messages.h
 drizzled/error.h
 drizzled/rpl_mi.cc
 drizzled/rpl_reporting.cc

=== modified file 'po/cy.po'
--- po/cy.po	2008-08-12 15:49:34 +0000
+++ po/cy.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 21:10+0000\n"
 "Last-Translator: nhutchings <natalie@nuttycrafts.co.uk>\n"
 "Language-Team: Welsh <cy@li.org>\n"
@@ -452,8 +452,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -569,8 +568,7 @@
 msgstr ""
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -632,7 +630,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1204,6 +1202,3316 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+#, fuzzy
+msgid "Sort aborted"
+msgstr "Terfynwyd"
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+#, fuzzy
+msgid "Unknown command"
+msgstr "rheolaeth anadnabyddus '\\%c'"
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, fuzzy, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr "rheolaeth anadnabyddus '\\%c'"
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+msgid "Incorrect partition name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1290,8 +4598,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1299,8 +4606,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1524,8 +4830,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/de.po'
--- po/de.po	2008-08-12 15:49:34 +0000
+++ po/de.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 21:56+0000\n"
 "Last-Translator: Hartmut Holzgraefe <hartmut@php.net>\n"
 "Language-Team: German <de@li.org>\n"
@@ -435,8 +435,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -559,8 +558,7 @@
 "Nichts gefunden"
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -622,7 +620,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1195,6 +1193,3330 @@
 msgid "Tablespace not empty"
 msgstr "Tablespace ist nicht leer"
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, fuzzy, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:42
+#, fuzzy, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:44
+#, fuzzy, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, fuzzy, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:60
+#, fuzzy, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:62
+#, fuzzy, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr "Datei kann nicht gesperrt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:64
+#, fuzzy, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr "Datei kann nicht gesperrt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:66
+#, fuzzy, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr "Datei kann nicht gesperrt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:68
+#, fuzzy, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:70
+#, fuzzy, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, fuzzy, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr "Fehler beim Lesen eines Packets vom Server: %s (Server-Fehler=%d)"
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+#, fuzzy
+msgid "Sort aborted"
+msgstr "Abgebrochen"
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, fuzzy, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+"Unerwartetes Dateiende beim Lesen von Datei '%s' gefunden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+#, fuzzy
+msgid "Unknown command"
+msgstr "Unbekanntes Kommando '\\%c'."
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, fuzzy, c-format
+msgid "Table '%-.192s' already exists"
+msgstr "Tablespace existiert bereits"
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+#, fuzzy
+msgid "No tables used"
+msgstr "Tablespace unbekannt"
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+#, fuzzy
+msgid "Unknown error"
+msgstr "Unbekannter Fehler %d"
+
+#: drizzled/drizzled_error_messages.h:244
+#, fuzzy, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr "Unbekannter Fehler %d"
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, fuzzy, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+#, fuzzy
+msgid "Could not create slave thread; check system resources"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, fuzzy, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr "Unbekanntes Kommando '\\%c'."
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+#, fuzzy
+msgid "Cursor is not open"
+msgstr "Zeichensatz nicht gefunden"
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+#, fuzzy
+msgid "Trigger already exists"
+msgstr "Tablespace existiert bereits"
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+#, fuzzy
+msgid "Unknown error during log purge"
+msgstr "Unbekannter Fehler %d"
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, fuzzy, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr "Datei kann nicht gesperrt werden (Fehlercode: %d)"
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+#, fuzzy
+msgid "Failed to create specific handler file"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, fuzzy, c-format
+msgid "Failed to create %s"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, fuzzy, c-format
+msgid "Failed to alter: %s"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+#, fuzzy
+msgid "Failed to open mysql.event"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+#, fuzzy
+msgid "Error during compilation of event's body"
+msgstr "Fehler beim Lesen eines Relaylog Ereignisses: %s"
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+#, fuzzy
+msgid "Incorrect partition name"
+msgstr "Leerzeichen hinter Funktionsnamen ignorieren."
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+#, fuzzy
+msgid "Nothing to backup"
+msgstr ""
+"\n"
+"Nichts gefunden"
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, fuzzy, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr "Tablespace existiert bereits"
+
+#: drizzled/drizzled_error_messages.h:1366
+#, fuzzy, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr "Tablespace existiert bereits"
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, fuzzy, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr "Tablespace ist nicht leer"
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1281,8 +4603,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1290,8 +4611,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1516,8 +4836,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/drizzle.pot'
--- po/drizzle.pot	2008-08-11 01:27:58 +0000
+++ po/drizzle.pot	2008-08-12 15:57:07 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: drizzle 7.0.0\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-07 14:44-0700\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -17,223 +17,223 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
 
-#: client/drizzle.c:260
+#: client/drizzle.cc:256
 msgid "Synonym for `help'."
 msgstr ""
 
-#: client/drizzle.c:261
+#: client/drizzle.cc:257
 msgid "Clear command."
 msgstr ""
 
-#: client/drizzle.c:263
+#: client/drizzle.cc:259
 msgid "Reconnect to the server. Optional arguments are db and host."
 msgstr ""
 
-#: client/drizzle.c:265
+#: client/drizzle.cc:261
 msgid ""
 "Set statement delimiter. NOTE: Takes the rest of the line as new delimiter."
 msgstr ""
 
-#: client/drizzle.c:267
+#: client/drizzle.cc:263
 msgid "Send command to drizzle server, display result vertically."
 msgstr ""
 
-#: client/drizzle.c:268
+#: client/drizzle.cc:264
 msgid "Exit drizzle. Same as quit."
 msgstr ""
 
-#: client/drizzle.c:269
+#: client/drizzle.cc:265
 msgid "Send command to drizzle server."
 msgstr ""
 
-#: client/drizzle.c:270
+#: client/drizzle.cc:266
 msgid "Display this help."
 msgstr ""
 
-#: client/drizzle.c:271
+#: client/drizzle.cc:267
 msgid "Disable pager, print to stdout."
 msgstr ""
 
-#: client/drizzle.c:272
+#: client/drizzle.cc:268
 msgid "Don't write into outfile."
 msgstr ""
 
-#: client/drizzle.c:274
+#: client/drizzle.cc:270
 msgid "Set PAGER [to_pager]. Print the query results via PAGER."
 msgstr ""
 
-#: client/drizzle.c:275
+#: client/drizzle.cc:271
 msgid "Print current command."
 msgstr ""
 
-#: client/drizzle.c:276
+#: client/drizzle.cc:272
 msgid "Change your drizzle prompt."
 msgstr ""
 
-#: client/drizzle.c:277
+#: client/drizzle.cc:273
 msgid "Quit drizzle."
 msgstr ""
 
-#: client/drizzle.c:278
+#: client/drizzle.cc:274
 msgid "Rebuild completion hash."
 msgstr ""
 
-#: client/drizzle.c:280
+#: client/drizzle.cc:276
 msgid "Execute an SQL script file. Takes a file name as an argument."
 msgstr ""
 
-#: client/drizzle.c:281
+#: client/drizzle.cc:277
 msgid "Get status information from the server."
 msgstr ""
 
-#: client/drizzle.c:283
+#: client/drizzle.cc:279
 msgid "Set outfile [to_outfile]. Append everything into given outfile."
 msgstr ""
 
-#: client/drizzle.c:285
+#: client/drizzle.cc:281
 msgid "Use another database. Takes database name as argument."
 msgstr ""
 
-#: client/drizzle.c:287
+#: client/drizzle.cc:283
 msgid ""
 "Switch to another charset. Might be needed for processing binlog with multi-"
 "byte charsets."
 msgstr ""
 
-#: client/drizzle.c:289 client/drizzle.c:1456
+#: client/drizzle.cc:285 client/drizzle.cc:1438
 msgid "Show warnings after every statement."
 msgstr ""
 
-#: client/drizzle.c:291
+#: client/drizzle.cc:287
 msgid "Don't show warnings after every statement."
 msgstr ""
 
-#: client/drizzle.c:1130
+#: client/drizzle.cc:1120
 msgid "Welcome to the Drizzle client..  Commands end with ; or \\g."
 msgstr ""
 
-#: client/drizzle.c:1138
+#: client/drizzle.cc:1130
 #, c-format
 msgid ""
 "Your Drizzle connection id is %u\n"
 "Server version: %s\n"
 msgstr ""
 
-#: client/drizzle.c:1168
+#: client/drizzle.cc:1160
 #, c-format
 msgid "Reading history-file %s\n"
 msgstr ""
 
-#: client/drizzle.c:1173
+#: client/drizzle.cc:1165
 #, c-format
 msgid "Couldn't allocate memory for temp histfile!\n"
 msgstr ""
 
-#: client/drizzle.c:1180
+#: client/drizzle.cc:1172
 msgid "Type 'help;' or '\\h' for help. Type '\\c' to clear the buffer.\n"
 msgstr ""
 
-#: client/drizzle.c:1199
+#: client/drizzle.cc:1191
 #, c-format
 msgid "Writing history-file %s\n"
 msgstr ""
 
-#: client/drizzle.c:1208
+#: client/drizzle.cc:1200
 msgid "Aborted"
 msgstr ""
 
-#: client/drizzle.c:1208
+#: client/drizzle.cc:1200
 msgid "Bye"
 msgstr ""
 
-#: client/drizzle.c:1261
+#: client/drizzle.cc:1249
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.c:1284 client/drizzleadmin.cc:69
+#: client/drizzle.cc:1272 client/drizzleadmin.cc:69
 msgid "Display this help and exit."
 msgstr ""
 
-#: client/drizzle.c:1286
+#: client/drizzle.cc:1274
 msgid "Synonym for -?"
 msgstr ""
 
-#: client/drizzle.c:1289
+#: client/drizzle.cc:1277
 msgid ""
 "Enable automatic rehashing. One doesn't need to use 'rehash' to get table "
 "and field completion, but startup and reconnecting may take a longer time. "
 "Disable with --disable-auto-rehash."
 msgstr ""
 
-#: client/drizzle.c:1293
+#: client/drizzle.cc:1281
 msgid ""
 "No automatic rehashing. One has to use 'rehash' to get table and field "
 "completion. This gives a quicker start of DRIZZLE and disables rehashing on "
 "reconnect. WARNING: options deprecated; use --disable-auto-rehash instead."
 msgstr ""
 
-#: client/drizzle.c:1296
+#: client/drizzle.cc:1284
 msgid ""
 "Automatically switch to vertical output mode if the result is wider than the "
 "terminal width."
 msgstr ""
 
-#: client/drizzle.c:1299
+#: client/drizzle.cc:1287
 msgid ""
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.c:1301
+#: client/drizzle.cc:1289
 msgid "Directory where character sets are."
 msgstr ""
 
-#: client/drizzle.c:1303
+#: client/drizzle.cc:1291
 msgid "Display column type information."
 msgstr ""
 
-#: client/drizzle.c:1306
+#: client/drizzle.cc:1294
 msgid ""
 "Preserve comments. Send comments to the server. The default is --skip-"
 "comments (discard comments), enable with --comments"
 msgstr ""
 
-#: client/drizzle.c:1309
+#: client/drizzle.cc:1297
 msgid "Use compression in server/client protocol."
 msgstr ""
 
-#: client/drizzle.c:1312
+#: client/drizzle.cc:1300
 msgid "Check memory and open file usage at exit ."
 msgstr ""
 
-#: client/drizzle.c:1315
+#: client/drizzle.cc:1303
 msgid "Print some debug info at exit."
 msgstr ""
 
-#: client/drizzle.c:1317
+#: client/drizzle.cc:1305
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.c:1320
+#: client/drizzle.cc:1308
 msgid "Set the default character set."
 msgstr ""
 
-#: client/drizzle.c:1322
+#: client/drizzle.cc:1310
 msgid "Delimiter to be used."
 msgstr ""
 
-#: client/drizzle.c:1324
+#: client/drizzle.cc:1312
 msgid "Execute command and quit. (Disables --force and history file)"
 msgstr ""
 
-#: client/drizzle.c:1326
+#: client/drizzle.cc:1314
 msgid "Print the output of a query (rows) vertically."
 msgstr ""
 
-#: client/drizzle.c:1329
+#: client/drizzle.cc:1317
 msgid "Continue even if we get an sql error."
 msgstr ""
 
-#: client/drizzle.c:1333
+#: client/drizzle.cc:1321
 msgid ""
 "Enable named commands. Named commands mean this program's internal commands; "
 "see drizzle> help . When enabled, the named commands can be used from any "
@@ -241,7 +241,7 @@
 "Disable with --disable-named-commands. This option is disabled by default."
 msgstr ""
 
-#: client/drizzle.c:1337
+#: client/drizzle.cc:1325
 msgid ""
 "Named commands are disabled. Use \\* form only, or use named commands only "
 "in the beginning of a line ending with a semicolon (;) Since version 10.9 "
@@ -250,71 +250,63 @@
 "deprecated; use --disable-named-commands instead."
 msgstr ""
 
-#: client/drizzle.c:1339
+#: client/drizzle.cc:1327
 msgid "Ignore space after function names."
 msgstr ""
 
-#: client/drizzle.c:1341
+#: client/drizzle.cc:1329
 msgid "Enable/disable LOAD DATA LOCAL INFILE."
 msgstr ""
 
-#: client/drizzle.c:1344
+#: client/drizzle.cc:1332
 msgid "Turn off beep on error."
 msgstr ""
 
-#: client/drizzle.c:1346 client/drizzleadmin.cc:71
+#: client/drizzle.cc:1334 client/drizzleadmin.cc:71
 msgid "Connect to host."
 msgstr ""
 
-#: client/drizzle.c:1348
-msgid "Produce HTML output."
-msgstr ""
-
-#: client/drizzle.c:1350
-msgid "Produce XML output"
-msgstr ""
-
-#: client/drizzle.c:1352
+#: client/drizzle.cc:1336
 msgid "Write line numbers for errors."
 msgstr ""
 
-#: client/drizzle.c:1355
+#: client/drizzle.cc:1339
 msgid ""
 "Don't write line number for errors. WARNING: -L is deprecated, use long "
 "version of this option instead."
 msgstr ""
 
-#: client/drizzle.c:1357
+#: client/drizzle.cc:1341
 msgid "Flush buffer after each query."
 msgstr ""
 
-#: client/drizzle.c:1359
+#: client/drizzle.cc:1343
 msgid "Write column names in results."
 msgstr ""
 
-#: client/drizzle.c:1363
+#: client/drizzle.cc:1347
 msgid ""
 "Don't write column names in results. WARNING: -N is deprecated, use long "
 "version of this options instead."
 msgstr ""
 
-#: client/drizzle.c:1366
+#: client/drizzle.cc:1350
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated; "
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: client/drizzle.c:1368
+#: client/drizzle.cc:1352
 msgid "Ignore SIGINT (CTRL-C)"
 msgstr ""
 
-#: client/drizzle.c:1372
+#: client/drizzle.cc:1356
 msgid ""
 "Only update the default database. This is useful for skipping updates to "
 "other database in the update log."
 msgstr ""
 
-#: client/drizzle.c:1375
+#: client/drizzle.cc:1359
 msgid ""
 "Pager to use to display results. If you don't supply an option the default "
 "pager is taken from your ENV variable PAGER. Valid pagers are less, more, "
@@ -323,136 +315,132 @@
 "default."
 msgstr ""
 
-#: client/drizzle.c:1378
+#: client/drizzle.cc:1362
 msgid ""
 "Disable pager and print to stdout. See interactive help (\\h) also. WARNING: "
 "option deprecated; use --disable-pager instead."
 msgstr ""
 
-#: client/drizzle.c:1381 client/drizzleadmin.cc:74
+#: client/drizzle.cc:1365 client/drizzleadmin.cc:74
 msgid ""
 "Password to use when connecting to server. If password is not given it's "
 "asked from the tty."
 msgstr ""
 
-#: client/drizzle.c:1383
+#: client/drizzle.cc:1367
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, "
 msgstr ""
 
-#: client/drizzle.c:1384
+#: client/drizzle.cc:1368
 msgid "built-in default"
 msgstr ""
 
-#: client/drizzle.c:1387
+#: client/drizzle.cc:1371
 msgid "Set the drizzle prompt to this value."
 msgstr ""
 
-#: client/drizzle.c:1390
+#: client/drizzle.cc:1374
 msgid "The protocol of connection (tcp,socket,pipe,memory)."
 msgstr ""
 
-#: client/drizzle.c:1393
+#: client/drizzle.cc:1377
 msgid ""
 "Don't cache result, print it row by row. This may slow down the server if "
 "the output is suspended. Doesn't use history file."
 msgstr ""
 
-#: client/drizzle.c:1395
+#: client/drizzle.cc:1379
 msgid "Write fields without conversion. Used with --batch."
 msgstr ""
 
-#: client/drizzle.c:1398
+#: client/drizzle.cc:1382
 msgid ""
 "Reconnect if the connection is lost. Disable with --disable-reconnect. This "
 "option is enabled by default."
 msgstr ""
 
-#: client/drizzle.c:1400
+#: client/drizzle.cc:1384
 msgid ""
 "Be more silent. Print results with a tab as separator, each row on new line."
 msgstr ""
 
-#: client/drizzle.c:1402
+#: client/drizzle.cc:1386
 msgid "Socket file to use for connection."
 msgstr ""
 
-#: client/drizzle.c:1405
+#: client/drizzle.cc:1389
 msgid "Output in table format."
 msgstr ""
 
-#: client/drizzle.c:1408
+#: client/drizzle.cc:1392
 msgid ""
 "Append everything into outfile. See interactive help (\\h) also. Does not "
 "work in batch mode. Disable with --disable-tee. This option is disabled by "
 "default."
 msgstr ""
 
-#: client/drizzle.c:1410
+#: client/drizzle.cc:1394
 msgid ""
 "Disable outfile. See interactive help (\\h) also. WARNING: option "
 "deprecated; use --disable-tee instead"
 msgstr ""
 
-#: client/drizzle.c:1413 client/drizzleadmin.cc:84
+#: client/drizzle.cc:1397 client/drizzleadmin.cc:84
 msgid "User for login if not current user."
 msgstr ""
 
-#: client/drizzle.c:1416
+#: client/drizzle.cc:1400
 msgid "Only allow UPDATE and DELETE that uses keys."
 msgstr ""
 
-#: client/drizzle.c:1419
+#: client/drizzle.cc:1403
 msgid "Synonym for option --safe-updates, -U."
 msgstr ""
 
-#: client/drizzle.c:1422
+#: client/drizzle.cc:1406
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.c:1424 client/drizzleadmin.cc:89
+#: client/drizzle.cc:1408 client/drizzleadmin.cc:89
 msgid "Output version information and exit."
 msgstr ""
 
-#: client/drizzle.c:1426 client/drizzleadmin.cc:91
+#: client/drizzle.cc:1410 client/drizzleadmin.cc:91
 msgid "Wait and retry if connection is down."
 msgstr ""
 
-#: client/drizzle.c:1429
+#: client/drizzle.cc:1413
 msgid "Number of seconds before connection timeout."
 msgstr ""
 
-#: client/drizzle.c:1434
+#: client/drizzle.cc:1418
 msgid "Max packet length to send to, or receive from server"
 msgstr ""
 
-#: client/drizzle.c:1439
+#: client/drizzle.cc:1423
 msgid "Buffer for TCP/IP and socket communication"
 msgstr ""
 
-#: client/drizzle.c:1443
+#: client/drizzle.cc:1427
 msgid "Automatic limit for SELECT when using --safe-updates"
 msgstr ""
 
-#: client/drizzle.c:1448
+#: client/drizzle.cc:1432
 msgid "Automatic limit for rows in a join when using --safe-updates"
 msgstr ""
 
-#: client/drizzle.c:1452
+#: client/drizzle.cc:1436
 msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
-#: client/drizzle.c:1454
-msgid "Send embedded server this as a parameter."
-msgstr ""
-
-#: client/drizzle.c:1467
+#: client/drizzle.cc:1449
 #, c-format
 msgid "%s  Ver %s Distrib %s, for %s (%s) using %s %s\n"
 msgstr ""
 
-#: client/drizzle.c:1474
+#: client/drizzle.cc:1456
 #, c-format
 msgid ""
 "Copyright (C) 2000-2008 MySQL AB\n"
@@ -461,158 +449,158 @@
 " and you are welcome to modify and redistribute it under the GPL license\n"
 msgstr ""
 
-#: client/drizzle.c:1478
+#: client/drizzle.cc:1460
 #, c-format
 msgid "Usage: %s [OPTIONS] [database]\n"
 msgstr ""
 
-#: client/drizzle.c:1511
+#: client/drizzle.cc:1493
 msgid "DELIMITER cannot contain a backslash character"
 msgstr ""
 
-#: client/drizzle.c:1532
+#: client/drizzle.cc:1514
 #, c-format
 msgid "WARNING: option deprecated; use --disable-tee instead.\n"
 msgstr ""
 
-#: client/drizzle.c:1555
+#: client/drizzle.cc:1537
 #, c-format
 msgid "WARNING: option deprecated; use --disable-pager instead.\n"
 msgstr ""
 
-#: client/drizzle.c:1559
+#: client/drizzle.cc:1541
 #, c-format
 msgid "WARNING: --server-arg option not supported in this configuration.\n"
 msgstr ""
 
-#: client/drizzle.c:1930
+#: client/drizzle.cc:1913
 #, c-format
 msgid "Unknown command '\\%c'."
 msgstr ""
 
-#: client/drizzle.c:2360
+#: client/drizzle.cc:2340
 msgid ""
 "Reading table information for completion of table and column names\n"
 "    You can turn off this feature to get a quicker startup with -A\n"
 "\n"
 msgstr ""
 
-#: client/drizzle.c:2457
+#: client/drizzle.cc:2437
 msgid "No connection. Trying to reconnect..."
 msgstr ""
 
-#: client/drizzle.c:2463
+#: client/drizzle.cc:2443
 msgid "Can't connect to the server\n"
 msgstr ""
 
-#: client/drizzle.c:2520
+#: client/drizzle.cc:2500
 msgid "categories:"
 msgstr ""
 
-#: client/drizzle.c:2520
+#: client/drizzle.cc:2500
 msgid "topics:"
 msgstr ""
 
-#: client/drizzle.c:2571
+#: client/drizzle.cc:2551
 #, c-format
 msgid "Name: '%s'\n"
 msgstr ""
 
-#: client/drizzle.c:2572
+#: client/drizzle.cc:2552
 #, c-format
 msgid ""
 "Description:\n"
 "%s"
 msgstr ""
 
-#: client/drizzle.c:2574
+#: client/drizzle.cc:2554
 #, c-format
 msgid ""
 "Examples:\n"
 "%s"
 msgstr ""
 
-#: client/drizzle.c:2587
+#: client/drizzle.cc:2567
 msgid "Many help items for your request exist."
 msgstr ""
 
-#: client/drizzle.c:2588
+#: client/drizzle.cc:2568
 msgid ""
 "To make a more specific request, please type 'help <item>',\n"
 "where <item> is one of the following"
 msgstr ""
 
-#: client/drizzle.c:2594
+#: client/drizzle.cc:2574
 #, c-format
 msgid "You asked for help about help category: '%s'\n"
 msgstr ""
 
-#: client/drizzle.c:2595
+#: client/drizzle.cc:2575
 msgid ""
 "For more information, type 'help <item>', where <item> is one of the "
 "following"
 msgstr ""
 
-#: client/drizzle.c:2608
+#: client/drizzle.cc:2588
 msgid ""
 "\n"
 "Nothing found"
 msgstr ""
 
-#: client/drizzle.c:2609
+#: client/drizzle.cc:2589
 msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
-#: client/drizzle.c:2632
+#: client/drizzle.cc:2611
 msgid "List of all Drizzle commands:"
 msgstr ""
 
-#: client/drizzle.c:2634
+#: client/drizzle.cc:2613
 msgid "Note that all text commands must be first on line and end with ';'"
 msgstr ""
 
-#: client/drizzle.c:2645
+#: client/drizzle.cc:2624
 msgid ""
 "\n"
 "For server side help, type 'help contents'\n"
 msgstr ""
 
-#: client/drizzle.c:2668
+#: client/drizzle.cc:2649
 msgid "Usage: \\C char_setname | charset charset_name"
 msgstr ""
 
-#: client/drizzle.c:2678
+#: client/drizzle.cc:2659
 msgid "Charset changed"
 msgstr ""
 
-#: client/drizzle.c:2680
+#: client/drizzle.cc:2661
 msgid "Charset is not found"
 msgstr ""
 
-#: client/drizzle.c:2711
+#: client/drizzle.cc:2692
 msgid "No query specified\n"
 msgstr ""
 
-#: client/drizzle.c:2726
+#: client/drizzle.cc:2707
 msgid "Ignoring query to other database"
 msgstr ""
 
-#: client/drizzle.c:2775
+#: client/drizzle.cc:2756
 msgid "Empty set"
 msgstr ""
 
-#: client/drizzle.c:2802
+#: client/drizzle.cc:2769
 #, c-format
 msgid "%ld row in set"
 msgid_plural "%ld rows in set"
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzle.c:2811
+#: client/drizzle.cc:2778
 msgid "Query OK"
 msgstr ""
 
-#: client/drizzle.c:2813
+#: client/drizzle.cc:2780
 #, c-format
 msgid "Query OK, %ld row affected"
 msgid_plural "Query OK, %ld rows affected"
@@ -889,40 +877,40 @@
 msgid "Info: "
 msgstr ""
 
-#: mysys/my_getopt.c:345
+#: mysys/my_getopt.c:350
 #, c-format
 msgid "%s: %s: Option '%s' used, but is disabled\n"
 msgstr ""
 
-#: mysys/my_getopt.c:346
+#: mysys/my_getopt.c:351
 msgid "WARNING"
 msgstr ""
 
-#: mysys/my_getopt.c:346
+#: mysys/my_getopt.c:351
 msgid "ERROR"
 msgstr ""
 
-#: mysys/my_getopt.c:449
+#: mysys/my_getopt.c:454
 #, c-format
 msgid "%s: ERROR: Option '-%c' used, but is disabled\n"
 msgstr ""
 
-#: mysys/my_getopt.c:762
+#: mysys/my_getopt.c:767
 #, c-format
 msgid "Unknown suffix '%c' used for variable '%s' (value '%s')\n"
 msgstr ""
 
-#: mysys/my_getopt.c:943
+#: mysys/my_getopt.c:948
 #, c-format
 msgid "%s: ERROR: Invalid decimal value for option '%s'\n"
 msgstr ""
 
-#: mysys/my_getopt.c:1165
+#: mysys/my_getopt.c:1170
 #, c-format
 msgid "%*s(Defaults to on; use --skip-%s to disable.)\n"
 msgstr ""
 
-#: mysys/my_getopt.c:1185
+#: mysys/my_getopt.c:1190
 #, c-format
 msgid ""
 "\n"
@@ -931,19 +919,19 @@
 "--------------------------------- -----------------------------\n"
 msgstr ""
 
-#: mysys/my_getopt.c:1201 mysys/my_getopt.c:1217
+#: mysys/my_getopt.c:1206 mysys/my_getopt.c:1222
 msgid "(No default value)"
 msgstr ""
 
-#: mysys/my_getopt.c:1220
+#: mysys/my_getopt.c:1225
 msgid "true"
 msgstr ""
 
-#: mysys/my_getopt.c:1220
+#: mysys/my_getopt.c:1225
 msgid "false"
 msgstr ""
 
-#: mysys/my_getopt.c:1245
+#: mysys/my_getopt.c:1250
 #, c-format
 msgid "(Disabled)\n"
 msgstr ""
@@ -1194,6 +1182,3314 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+msgid "Sort aborted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+msgid "Unknown command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+msgid "Incorrect partition name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2008-08-12 15:49:34 +0000
+++ po/en_GB.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 18:57+0000\n"
 "Last-Translator: LinuxJedi <andrew@linuxjedi.co.uk>\n"
 "Language-Team: English (United Kingdom) <en_GB@li.org>\n"
@@ -433,8 +433,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -550,8 +549,7 @@
 msgstr ""
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -613,7 +611,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1185,6 +1183,3315 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+#, fuzzy
+msgid "Sort aborted"
+msgstr "Aborted"
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+msgid "Unknown command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+msgid "Incorrect partition name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1271,8 +4578,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1280,8 +4586,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1505,8 +4810,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/es.po'
--- po/es.po	2008-08-12 15:49:34 +0000
+++ po/es.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 21:54+0000\n"
 "Last-Translator: jabi <jabi@irontec.com>\n"
 "Language-Team: Spanish <es@li.org>\n"
@@ -445,8 +445,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -562,8 +561,7 @@
 msgstr ""
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -625,7 +623,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1197,6 +1195,3314 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+msgid "Sort aborted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+msgid "Unknown command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+msgid "Incorrect partition name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1283,8 +4589,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1292,8 +4597,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1517,8 +4821,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/nb.po'
--- po/nb.po	2008-08-12 15:49:34 +0000
+++ po/nb.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 21:47+0000\n"
 "Last-Translator: matslindh <Unknown>\n"
 "Language-Team: Norwegian Bokmal <nb@li.org>\n"
@@ -199,8 +199,7 @@
 #: client/drizzle.cc:1287
 msgid ""
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
-msgstr ""
-"Ikke bruk en historiefil. Skru av interaktivitet. (Skrur på --silent)"
+msgstr "Ikke bruk en historiefil. Skru av interaktivitet. (Skrur på --silent)"
 
 #: client/drizzle.cc:1289
 msgid "Directory where character sets are."
@@ -490,8 +489,7 @@
 "er skrudd på."
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 "Avbryt tilkoblingen til serveren dersom den bruker den gamle (før 4.1.1) "
 "protokollen."
@@ -622,8 +620,7 @@
 "Ingenting ble funnet"
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 "Prøv å kjør 'help contents' for en liste over alle tilgjengelige emner\n"
 
@@ -690,7 +687,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1271,6 +1268,3323 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, fuzzy, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr "Kan ikke lage/skrive til filen '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:42
+#, fuzzy, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr "Kan ikke lage/skrive til filen '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:44
+#, fuzzy, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr "Kan ikke lage katalogen '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, fuzzy, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr "Feil ved slettingen av '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, fuzzy, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr "Feil ved slettingen av '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, fuzzy, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr "Kan ikke 'stat'-e '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:60
+#, fuzzy, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr "Fikk ikke tak i arbeidskatalogen (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:62
+#, fuzzy, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr "Kan ikke låse filen (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:64
+#, fuzzy, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr "Kan ikke låse filen (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:66
+#, fuzzy, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr "Kan ikke lage/skrive til filen '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:68
+#, fuzzy, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr "Kan ikke lese katalogen '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:70
+#, fuzzy, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr "Kunne ikke bytte katalog til '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, fuzzy, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+"Disken er full når vi prøver å skrive '%s'. Venter på at noen skal frigi "
+"plass..."
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, fuzzy, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr "Feil ved lukkingen av '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:80
+#, fuzzy, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr "Lesingen av '%s' mislykkes (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:82
+#, fuzzy, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr "Klarte ikke å bytte navn på '%s' til '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:84
+#, fuzzy, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr "Skrivingen av '%s' mislykkes (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+#, fuzzy
+msgid "Sort aborted"
+msgstr "Avbrutt"
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, fuzzy, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr "Tomt for minne (Trengte %u bytes)"
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, fuzzy, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr "Uventet slutt-på-fil (EOF) inntraff da vi leste '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+#, fuzzy
+msgid "Unknown command"
+msgstr "Ukjent kommando '\\%c'."
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, fuzzy, c-format
+msgid "Unknown database '%-.192s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, fuzzy, c-format
+msgid "Unknown table '%-.100s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, fuzzy, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, fuzzy, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, fuzzy, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, fuzzy, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr "Kan ikke lage katalogen '%s' (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, fuzzy, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, fuzzy, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr "Kan ikke lese verdien av symlinken '%s' (Error: %d)"
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, fuzzy, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, fuzzy, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, fuzzy, c-format
+msgid "Unknown table engine '%s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:606
+#, fuzzy, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr "ADVARSEL: egenskapen er utgått; bruk --disable-tee i stedet.\n"
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, fuzzy, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+#, fuzzy
+msgid "Cursor is not open"
+msgstr "Tegnsettet ble ikke funnet"
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, fuzzy, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr "Kan ikke låse filen (Feilkode: %d)"
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, fuzzy, c-format
+msgid "Unknown event '%-.192s'"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+#, fuzzy
+msgid "Incorrect partition name"
+msgstr "Overse mellomrom etter funksjonsnavn."
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, fuzzy, c-format
+msgid "Fatal error: %s"
+msgstr "Fikk feil: %s\n"
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+#, fuzzy
+msgid "Nothing to backup"
+msgstr ""
+"\n"
+"Ingenting ble funnet"
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1357,8 +4671,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1366,8 +4679,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1591,8 +4903,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/nl.po'
--- po/nl.po	2008-08-12 15:49:34 +0000
+++ po/nl.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 22:30+0000\n"
 "Last-Translator: Mark Daems <Unknown>\n"
 "Language-Team: Dutch <nl@li.org>\n"
@@ -28,8 +28,7 @@
 
 #: client/drizzle.cc:259
 msgid "Reconnect to the server. Optional arguments are db and host."
-msgstr ""
-"Opnieuw verbinden met de server. Optionele argumenten zijn db en host."
+msgstr "Opnieuw verbinden met de server. Optionele argumenten zijn db en host."
 
 #: client/drizzle.cc:261
 #, fuzzy
@@ -41,8 +40,7 @@
 
 #: client/drizzle.cc:263
 msgid "Send command to drizzle server, display result vertically."
-msgstr ""
-"Verstuur opdracht naar de drizzle server, toon het resultaat verticaal"
+msgstr "Verstuur opdracht naar de drizzle server, toon het resultaat verticaal"
 
 #: client/drizzle.cc:264
 msgid "Exit drizzle. Same as quit."
@@ -86,8 +84,7 @@
 
 #: client/drizzle.cc:276
 msgid "Execute an SQL script file. Takes a file name as an argument."
-msgstr ""
-"Voer een SQL script bestand uit. Neemt een bestandsnaam als argument."
+msgstr "Voer een SQL script bestand uit. Neemt een bestandsnaam als argument."
 
 #: client/drizzle.cc:277
 msgid "Get status information from the server."
@@ -458,8 +455,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -575,8 +571,7 @@
 msgstr ""
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -638,7 +633,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1210,6 +1205,3316 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+#, fuzzy
+msgid "Sort aborted"
+msgstr "Afgebroken"
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+msgid "Unknown command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+#, fuzzy
+msgid "Incorrect partition name"
+msgstr "Negeer spaties na functienamen."
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1296,8 +4601,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1305,8 +4609,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1530,8 +4833,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/ro.po'
--- po/ro.po	2008-08-12 15:49:34 +0000
+++ po/ro.po	2008-08-12 15:57:07 +0000
@@ -6,8 +6,8 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 19:56+0000\n"
 "Last-Translator: Mihai <Unknown>\n"
 "Language-Team: Romanian <ro@li.org>\n"
@@ -434,8 +434,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -551,8 +550,7 @@
 msgstr ""
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -614,7 +612,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1186,6 +1184,3314 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+msgid "Sort aborted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+msgid "Unknown command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+msgid "Incorrect partition name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1272,8 +4578,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1281,8 +4586,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1506,8 +4810,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'po/ru.po'
--- po/ru.po	2008-08-12 15:49:34 +0000
+++ po/ru.po	2008-08-12 15:57:07 +0000
@@ -6,16 +6,16 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: drizzle\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2008-08-11 11:00-0700\n"
+"Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
+"POT-Creation-Date: 2008-08-12 08:55-0700\n"
 "PO-Revision-Date: 2008-08-11 22:17+0000\n"
 "Last-Translator: Alexey Kovyrin <Unknown>\n"
 "Language-Team: Russian <ru@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && "
-"n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
+"Plural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%"
+"10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Launchpad-Export-Date: 2008-08-12 04:16+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
@@ -453,8 +453,7 @@
 msgstr ""
 
 #: client/drizzle.cc:1436
-msgid ""
-"Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
+msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
 msgstr ""
 
 #: client/drizzle.cc:1449
@@ -570,8 +569,7 @@
 msgstr ""
 
 #: client/drizzle.cc:2589
-msgid ""
-"Please try to run 'help contents' for a list of all accessible topics\n"
+msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
 
 #: client/drizzle.cc:2611
@@ -633,7 +631,7 @@
 #: client/drizzleadmin.cc:76
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
-"preference, my.cnf, $MYSQL_TCP_PORT, built-in default ("
+"preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 
 #: client/drizzleadmin.cc:81
@@ -1205,6 +1203,3315 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/drizzled_error_messages.h:32
+msgid "hashchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:34
+msgid "isamchk"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:36
+msgid "NO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:38
+msgid "YES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:40
+#, c-format
+msgid "Can't create file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:42
+#, c-format
+msgid "Can't create table '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:44
+#, c-format
+msgid "Can't create database '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:46
+#, c-format
+msgid "Can't create database '%-.192s'; database exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:48
+#, c-format
+msgid "Can't drop database '%-.192s'; database doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:50
+#, c-format
+msgid "Error dropping database (can't delete '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:52
+#, c-format
+msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:54
+#, c-format
+msgid "Error on delete of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:56
+msgid "Can't read record in system table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:58
+#, c-format
+msgid "Can't get status of '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:60
+#, c-format
+msgid "Can't get working directory (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:62
+#, c-format
+msgid "Can't lock file (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:64
+#, c-format
+msgid "Can't open file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:66
+#, c-format
+msgid "Can't find file: '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:68
+#, c-format
+msgid "Can't read dir of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:70
+#, c-format
+msgid "Can't change dir to '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:72
+#, c-format
+msgid "Record has changed since last read in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:74
+#, c-format
+msgid "Disk full (%s); waiting for someone to free some space..."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:76
+#, c-format
+msgid "Can't write; duplicate key in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:78
+#, c-format
+msgid "Error on close of '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:80
+#, c-format
+msgid "Error reading file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:82
+#, c-format
+msgid "Error on rename of '%-.150s' to '%-.150s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:84
+#, c-format
+msgid "Error writing file '%-.200s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:86
+#, c-format
+msgid "'%-.192s' is locked against change"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:88
+#, fuzzy
+msgid "Sort aborted"
+msgstr "Отменено"
+
+#: drizzled/drizzled_error_messages.h:90
+#, c-format
+msgid "View '%-.192s' doesn't exist for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:92
+#, c-format
+msgid "Got error %d from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:94
+#, c-format
+msgid "Table storage engine for '%-.192s' doesn't have this option"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:96
+#, c-format
+msgid "Can't find record in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:98
+#, c-format
+msgid "Incorrect information in file: '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:100
+#, c-format
+msgid "Incorrect key file for table '%-.200s'; try to repair it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:102
+#, c-format
+msgid "Old key file for table '%-.192s'; repair it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:104
+#, c-format
+msgid "Table '%-.192s' is read only"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:106
+#, c-format
+msgid "Out of memory; restart server and try again (needed %d bytes)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:108
+msgid "Out of sort memory; increase server sort buffer size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:110
+#, c-format
+msgid "Unexpected EOF found when reading file '%-.192s' (errno: %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:112
+msgid "Too many connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:114
+msgid ""
+"Out of memory; check if mysqld or some other process uses all available "
+"memory; if not, you may have to use 'ulimit' to allow mysqld to use more "
+"memory or you can add more swap space"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:116
+msgid "Can't get hostname for your address"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:118
+msgid "Bad handshake"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:120
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' to database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:122
+#, c-format
+msgid "Access denied for user '%-.48s'@'%-.64s' (using password: %s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:124
+msgid "No database selected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:126
+msgid "Unknown command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:128
+#, c-format
+msgid "Column '%-.192s' cannot be null"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:130
+#, c-format
+msgid "Unknown database '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:132
+#, c-format
+msgid "Table '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:134
+#, c-format
+msgid "Unknown table '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:136
+#, c-format
+msgid "Column '%-.192s' in %-.192s is ambiguous"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:138
+msgid "Server shutdown in progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:140
+#, c-format
+msgid "Unknown column '%-.192s' in '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:142
+#, c-format
+msgid "'%-.192s' isn't in GROUP BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:144
+#, c-format
+msgid "Can't group on '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:146
+msgid "Statement has sum functions and columns in same statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:148
+msgid "Column count doesn't match value count"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:150
+#, c-format
+msgid "Identifier name '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:152
+#, c-format
+msgid "Duplicate column name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:154
+#, c-format
+msgid "Duplicate key name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:156
+#, c-format
+msgid "Duplicate entry '%-.192s' for key %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:158
+#, c-format
+msgid "Incorrect column specifier for column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:160
+#, c-format
+msgid "%s near '%-.80s' at line %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:162
+msgid "Query was empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:164
+#, c-format
+msgid "Not unique table/alias: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:166
+#, c-format
+msgid "Invalid default value for '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:168
+msgid "Multiple primary key defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:170
+#, c-format
+msgid "Too many keys specified; max %d keys allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:172
+#, c-format
+msgid "Too many key parts specified; max %d parts allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:174
+#, c-format
+msgid "Specified key was too long; max key length is %d bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:176
+#, c-format
+msgid "Key column '%-.192s' doesn't exist in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:178
+#, c-format
+msgid ""
+"BLOB column '%-.192s' can't be used in key specification with the used table "
+"type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:180
+#, c-format
+msgid ""
+"Column length too big for column '%-.192s' (max = %d); use BLOB or TEXT "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:182
+msgid ""
+"Incorrect table definition; there can be only one auto column and it must be "
+"defined as a key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:184
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:186
+#, c-format
+msgid "%s: Normal shutdown\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:188
+#, c-format
+msgid "%s: Got signal %d. Aborting!\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:190
+#, c-format
+msgid "%s: Shutdown complete\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:192
+#, c-format
+msgid "%s: Forcing close of thread %ld  user: '%-.48s'\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:194
+msgid "Can't create IP socket"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:196
+#, c-format
+msgid ""
+"Table '%-.192s' has no index like the one used in CREATE INDEX; recreate the "
+"table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:198
+msgid "Field separator argument is not what is expected; check the manual"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:200
+msgid ""
+"You can't use fixed rowlength with BLOBs; please use 'fields terminated by'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:202
+#, c-format
+msgid ""
+"The file '%-.128s' must be in the database directory or be readable by all"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:204
+#, c-format
+msgid "File '%-.200s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:206
+#, c-format
+msgid "Records: %ld  Deleted: %ld  Skipped: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:208
+#, c-format
+msgid "Records: %ld  Duplicates: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:210
+msgid ""
+"Incorrect prefix key; the used key part isn't a string, the used length is "
+"longer than the key part, or the storage engine doesn't support unique "
+"prefix keys"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:212
+msgid "You can't delete all columns with ALTER TABLE; use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:214
+#, c-format
+msgid "Can't DROP '%-.192s'; check that column/key exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:216
+#, c-format
+msgid "Records: %ld  Duplicates: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:218
+#, c-format
+msgid "You can't specify target table '%-.192s' for update in FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:220
+#, c-format
+msgid "Unknown thread id: %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:222
+#, c-format
+msgid "You are not owner of thread %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:224
+msgid "No tables used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:226
+#, c-format
+msgid "Too many strings for column %-.192s and SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:228
+#, c-format
+msgid "Can't generate a unique log-filename %-.200s.(1-999)\n"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:230
+#, c-format
+msgid "Table '%-.192s' was locked with a READ lock and can't be updated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:232
+#, c-format
+msgid "Table '%-.192s' was not locked with LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:234
+#, c-format
+msgid "BLOB/TEXT column '%-.192s' can't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:236
+#, c-format
+msgid "Incorrect database name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:238
+#, c-format
+msgid "Incorrect table name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:240
+msgid ""
+"The SELECT would examine more than MAX_JOIN_SIZE rows; check your WHERE and "
+"use SET SQL_BIG_SELECTS=1 or SET SQL_MAX_JOIN_SIZE=# if the SELECT is okay"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:242
+msgid "Unknown error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:244
+#, c-format
+msgid "Unknown procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:246
+#, c-format
+msgid "Incorrect parameter count to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:248
+#, c-format
+msgid "Incorrect parameters to procedure '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:250
+#, c-format
+msgid "Unknown table '%-.192s' in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:252
+#, c-format
+msgid "Column '%-.192s' specified twice"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:254
+msgid "Invalid use of group function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:256
+#, c-format
+msgid ""
+"Table '%-.192s' uses an extension that doesn't exist in this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:258
+msgid "A table must have at least 1 column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:260
+#, c-format
+msgid "The table '%-.192s' is full"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:262
+#, c-format
+msgid "Unknown character set: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:264
+#, c-format
+msgid "Too many tables; MySQL can only use %d tables in a join"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:266
+msgid "Too many columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:268
+#, c-format
+msgid ""
+"Row size too large. The maximum row size for the used table type, not "
+"counting BLOBs, is %ld. You have to change some columns to TEXT or BLOBs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:270
+#, c-format
+msgid ""
+"Thread stack overrun:  Used: %ld of a %ld stack.  Use 'mysqld -O "
+"thread_stack=#' to specify a bigger stack if needed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:272
+msgid "Cross dependency found in OUTER JOIN; examine your ON conditions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:274
+#, c-format
+msgid ""
+"Table handler doesn't support NULL in given index. Please change column "
+"'%-.192s' to be NOT NULL or use another handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:276
+#, c-format
+msgid "Can't load function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:278
+#, c-format
+msgid "Can't initialize function '%-.192s'; %-.80s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:280
+msgid "No paths allowed for shared library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:282
+#, c-format
+msgid "Function '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:284
+#, c-format
+msgid "Can't open shared library '%-.192s' (errno: %d %-.128s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:286
+#, c-format
+msgid "Can't find symbol '%-.128s' in library"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:288
+#, c-format
+msgid "Function '%-.192s' is not defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:290
+#, c-format
+msgid ""
+"Host '%-.64s' is blocked because of many connection errors; unblock with "
+"'mysqladmin flush-hosts'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:292
+#, c-format
+msgid "Host '%-.64s' is not allowed to connect to this MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:294
+msgid ""
+"You are using MySQL as an anonymous user and anonymous users are not allowed "
+"to change passwords"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:296
+msgid ""
+"You must have privileges to update tables in the mysql database to be able "
+"to change passwords for others"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:298
+msgid "Can't find any matching row in the user table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:300
+#, c-format
+msgid "Rows matched: %ld  Changed: %ld  Warnings: %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:302
+#, c-format
+msgid ""
+"Can't create a new thread (errno %d); if you are not out of available "
+"memory, you can consult the manual for a possible OS-dependent bug"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:304
+#, c-format
+msgid "Column count doesn't match value count at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:306
+#, c-format
+msgid "Can't reopen table: '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:308
+msgid "Invalid use of NULL value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:310
+#, c-format
+msgid "Got error '%-.64s' from regexp"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:312
+msgid ""
+"Mixing of GROUP columns (MIN(),MAX(),COUNT(),...) with no GROUP columns is "
+"illegal if there is no GROUP BY clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:314
+#, c-format
+msgid "There is no such grant defined for user '%-.48s' on host '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:316
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:318
+#, c-format
+msgid ""
+"%-.16s command denied to user '%-.48s'@'%-.64s' for column '%-.192s' in "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:320
+msgid ""
+"Illegal GRANT/REVOKE command; please consult the manual to see which "
+"privileges can be used"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:322
+msgid "The host or user argument to GRANT is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:324
+#, c-format
+msgid "Table '%-.192s.%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:326
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on table "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:328
+msgid "The used command is not allowed with this MySQL version"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:330
+msgid ""
+"You have an error in your SQL syntax; check the manual that corresponds to "
+"your MySQL server version for the right syntax to use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:332
+#, c-format
+msgid "Delayed insert thread couldn't get requested lock for table %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:334
+msgid "Too many delayed threads in use"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:336
+#, c-format
+msgid "Aborted connection %ld to db: '%-.192s' user: '%-.48s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:338
+msgid "Got a packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:340
+msgid "Got a read error from the connection pipe"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:342
+msgid "Got an error from fcntl()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:344
+msgid "Got packets out of order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:346
+msgid "Couldn't uncompress communication packet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:348
+msgid "Got an error reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:350
+msgid "Got timeout reading communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:352
+msgid "Got an error writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:354
+msgid "Got timeout writing communication packets"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:356
+msgid "Result string is longer than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:358
+msgid "The used table type doesn't support BLOB/TEXT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:360
+msgid "The used table type doesn't support AUTO_INCREMENT columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:362
+#, c-format
+msgid ""
+"INSERT DELAYED can't be used with table '%-.192s' because it is locked with "
+"LOCK TABLES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:364
+#, c-format
+msgid "Incorrect column name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:366
+#, c-format
+msgid "The used storage engine can't index column '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:368
+msgid ""
+"Unable to open underlying table which is differently defined or of non-"
+"MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:370
+#, c-format
+msgid "Can't write, because of unique constraint, to table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:372
+#, c-format
+msgid ""
+"BLOB/TEXT column '%-.192s' used in key specification without a key length"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:374
+msgid ""
+"All parts of a PRIMARY KEY must be NOT NULL; if you need NULL in a key, use "
+"UNIQUE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:376
+msgid "Result consisted of more than one row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:378
+msgid "This table type requires a primary key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:380
+msgid "This version of MySQL is not compiled with RAID support"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:382
+msgid ""
+"You are using safe update mode and you tried to update a table without a "
+"WHERE that uses a KEY column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:384
+#, c-format
+msgid "Key '%-.192s' doesn't exist in table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:386
+msgid "Can't open table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:388
+#, c-format
+msgid "The storage engine for the table doesn't support %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:390
+msgid "You are not allowed to execute this command in a transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:392
+#, c-format
+msgid "Got error %d during COMMIT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:394
+#, c-format
+msgid "Got error %d during ROLLBACK"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:396
+#, c-format
+msgid "Got error %d during FLUSH_LOGS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:398
+#, c-format
+msgid "Got error %d during CHECKPOINT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:400
+#, c-format
+msgid ""
+"Aborted connection %ld to db: '%-.192s' user: '%-.48s' host: "
+"'%-.64s' (%-.64s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:402
+msgid "The storage engine for the table does not support binary table dump"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:404
+msgid "Binlog closed, cannot RESET MASTER"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:406
+#, c-format
+msgid "Failed rebuilding the index of  dumped table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:408
+#, c-format
+msgid "Error from master: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:410
+msgid "Net error reading from master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:412
+msgid "Net error writing to master"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:414
+msgid "Can't find FULLTEXT index matching the column list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:416
+msgid ""
+"Can't execute the given command because you have active locked tables or an "
+"active transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:418
+#, c-format
+msgid "Unknown system variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:420
+#, c-format
+msgid "Table '%-.192s' is marked as crashed and should be repaired"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:422
+#, c-format
+msgid ""
+"Table '%-.192s' is marked as crashed and last (automatic?) repair failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:424
+msgid "Some non-transactional changed tables couldn't be rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:426
+msgid ""
+"Multi-statement transaction required more than 'max_binlog_cache_size' bytes "
+"of storage; increase this mysqld variable and try again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:428
+msgid ""
+"This operation cannot be performed with a running slave; run STOP SLAVE first"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:430
+msgid ""
+"This operation requires a running slave; configure slave and do START SLAVE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:432
+msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:434
+msgid ""
+"Could not initialize master info structure; more error messages can be found "
+"in the MySQL error log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:436
+msgid "Could not create slave thread; check system resources"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:438
+#, c-format
+msgid ""
+"User %-.64s already has more than 'max_user_connections' active connections"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:440
+msgid "You may only use constant expressions with SET"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:442
+msgid "Lock wait timeout exceeded; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:444
+msgid "The total number of locks exceeds the lock table size"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:446
+msgid "Update locks cannot be acquired during a READ UNCOMMITTED transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:448
+msgid "DROP DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:450
+msgid "CREATE DATABASE not allowed while thread is holding global read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:452
+#, c-format
+msgid "Incorrect arguments to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:454
+#, c-format
+msgid "'%-.48s'@'%-.64s' is not allowed to create new users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:456
+msgid ""
+"Incorrect table definition; all MERGE tables must be in the same database"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:458
+msgid "Deadlock found when trying to get lock; try restarting transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:460
+msgid "The used table type doesn't support FULLTEXT indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:462
+msgid "Cannot add foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:464
+msgid "Cannot add or update a child row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:466
+msgid "Cannot delete or update a parent row: a foreign key constraint fails"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:468
+#, c-format
+msgid "Error connecting to master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:470
+#, c-format
+msgid "Error running query on master: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:472
+#, c-format
+msgid "Error when executing command %s: %-.128s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:474
+#, c-format
+msgid "Incorrect usage of %s and %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:476
+msgid "The used SELECT statements have a different number of columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:478
+msgid "Can't execute the query because you have a conflicting read lock"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:480
+msgid "Mixing of transactional and non-transactional tables is disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:482
+#, c-format
+msgid "Option '%s' used twice in statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:484
+#, c-format
+msgid "User '%-.64s' has exceeded the '%s' resource (current value: %ld)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:486
+#, c-format
+msgid "Access denied; you need the %-.128s privilege for this operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:488
+#, c-format
+msgid ""
+"Variable '%-.64s' is a SESSION variable and can't be used with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:490
+#, c-format
+msgid ""
+"Variable '%-.64s' is a GLOBAL variable and should be set with SET GLOBAL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:492
+#, c-format
+msgid "Variable '%-.64s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:494
+#, c-format
+msgid "Variable '%-.64s' can't be set to the value of '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:496
+#, c-format
+msgid "Incorrect argument type to variable '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:498
+#, c-format
+msgid "Variable '%-.64s' can only be set, not read"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:500
+#, c-format
+msgid "Incorrect usage/placement of '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:502
+#, c-format
+msgid "This version of MySQL doesn't yet support '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:504
+#, c-format
+msgid ""
+"Got fatal error %d: '%-.128s' from master when reading data from binary log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:506
+msgid "Slave SQL thread ignored the query because of replicate-*-table rules"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:508
+#, c-format
+msgid "Variable '%-.192s' is a %s variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:510
+#, c-format
+msgid "Incorrect foreign key definition for '%-.192s': %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:512
+msgid "Key reference and table reference don't match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:514
+#, c-format
+msgid "Operand should contain %d column(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:516
+msgid "Subquery returns more than 1 row"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:518
+#, c-format
+msgid "Unknown prepared statement handler (%.*s) given to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:520
+msgid "Help database is corrupt or does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:522
+msgid "Cyclic reference on subqueries"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:524
+#, c-format
+msgid "Converting column '%s' from %s to %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:526
+#, c-format
+msgid "Reference '%-.64s' not supported (%s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:528
+msgid "Every derived table must have its own alias"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:530
+#, c-format
+msgid "Select %u was reduced during optimization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:532
+#, c-format
+msgid "Table '%-.192s' from one of the SELECTs cannot be used in %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:534
+msgid ""
+"Client does not support authentication protocol requested by server; "
+"consider upgrading MySQL client"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:536
+msgid "All parts of a SPATIAL index must be NOT NULL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:538
+#, c-format
+msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:540
+msgid "Slave is already running"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:542
+msgid "Slave already has been stopped"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:544
+#, c-format
+msgid ""
+"Uncompressed data size too large; the maximum size is %d (probably, length "
+"of uncompressed data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:546
+msgid "ZLIB: Not enough memory"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:548
+msgid ""
+"ZLIB: Not enough room in the output buffer (probably, length of uncompressed "
+"data was corrupted)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:550
+msgid "ZLIB: Input data corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:552
+#, c-format
+msgid "%d line(s) were cut by GROUP_CONCAT()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:554
+#, c-format
+msgid "Row %ld doesn't contain data for all columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:556
+#, c-format
+msgid ""
+"Row %ld was truncated; it contained more data than there were input columns"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:558
+#, c-format
+msgid ""
+"Column set to default value; NULL supplied to NOT NULL column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:560
+#, c-format
+msgid "Out of range value for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:562
+#, c-format
+msgid "Data truncated for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:564
+#, c-format
+msgid "Using storage engine %s for table '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:566
+#, c-format
+msgid "Illegal mix of collations (%s,%s) and (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:568
+msgid "Cannot drop one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:570
+msgid "Can't revoke all privileges for one or more of the requested users"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:572
+#, c-format
+msgid "Illegal mix of collations (%s,%s), (%s,%s), (%s,%s) for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:574
+#, c-format
+msgid "Illegal mix of collations for operation '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:576
+#, c-format
+msgid ""
+"Variable '%-.64s' is not a variable component (can't be used as XXXX."
+"variable_name)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:578
+#, c-format
+msgid "Unknown collation: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:580
+msgid ""
+"SSL parameters in CHANGE MASTER are ignored because this MySQL slave was "
+"compiled without SSL support; they can be used later if MySQL slave with SSL "
+"is started"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:582
+#, c-format
+msgid ""
+"Server is running in --secure-auth mode, but '%s'@'%s' has a password in the "
+"old format; please change the password to the new format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:584
+#, c-format
+msgid ""
+"Field or reference '%-.192s%s%-.192s%s%-.192s' of SELECT #%d was resolved in "
+"SELECT #%d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:586
+msgid "Incorrect parameter or combination of parameters for START SLAVE UNTIL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:588
+msgid ""
+"It is recommended to use --skip-slave-start when doing step-by-step "
+"replication with START SLAVE UNTIL; otherwise, you will get problems if you "
+"get an unexpected slave's mysqld restart"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:590
+msgid "SQL thread is not to be started so UNTIL options are ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:592
+#, c-format
+msgid "Incorrect index name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:594
+#, c-format
+msgid "Incorrect catalog name '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:596
+#, c-format
+msgid "Query cache failed to set size %lu; new query cache size is %lu"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:598
+#, c-format
+msgid "Column '%-.192s' cannot be part of FULLTEXT index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:600
+#, c-format
+msgid "Unknown key cache '%-.100s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:602
+msgid ""
+"MySQL is started in --skip-name-resolve mode; you must restart it without "
+"this switch for this grant to work"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:604
+#, c-format
+msgid "Unknown table engine '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:606
+#, c-format
+msgid "'%s' is deprecated; use '%s' instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:608
+#, c-format
+msgid "The target table %-.100s of the %s is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:610
+#, c-format
+msgid ""
+"The '%s' feature is disabled; you need MySQL built with '%s' to have it "
+"working"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:612
+#, c-format
+msgid ""
+"The MySQL server is running with the %s option so it cannot execute this "
+"statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:614
+#, c-format
+msgid "Column '%-.100s' has duplicated value '%-.64s' in %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:616
+#, c-format
+msgid "Truncated incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:618
+msgid ""
+"Incorrect table definition; there can be only one TIMESTAMP column with "
+"CURRENT_TIMESTAMP in DEFAULT or ON UPDATE clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:620
+#, c-format
+msgid "Invalid ON UPDATE clause for '%-.192s' column"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:622
+msgid "This command is not supported in the prepared statement protocol yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:624
+#, c-format
+msgid "Got error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:626
+#, c-format
+msgid "Got temporary error %d '%-.100s' from %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:628
+#, c-format
+msgid "Unknown or incorrect time zone: '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:630
+#, c-format
+msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:632
+#, c-format
+msgid "Invalid %s character string: '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:634
+#, c-format
+msgid "Result of %s() was larger than max_allowed_packet (%ld) - truncated"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:636
+#, c-format
+msgid "Conflicting declarations: '%s%s' and '%s%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:638
+#, c-format
+msgid "Can't create a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:640
+#, c-format
+msgid "%s %s already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:642
+#, c-format
+msgid "%s %s does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:644
+#, c-format
+msgid "Failed to DROP %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:646
+#, c-format
+msgid "Failed to CREATE %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:648
+#, c-format
+msgid "%s with no matching label: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:650
+#, c-format
+msgid "Redefining label %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:652
+#, c-format
+msgid "End-label %s without match"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:654
+#, c-format
+msgid "Referring to uninitialized variable %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:656
+#, c-format
+msgid "PROCEDURE %s can't return a result set in the given context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:658
+msgid "RETURN is only allowed in a FUNCTION"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:660
+#, c-format
+msgid "%s is not allowed in stored procedures"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:662
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been ignored"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:664
+msgid ""
+"The update log is deprecated and replaced by the binary log; SET "
+"SQL_LOG_UPDATE has been translated to SET SQL_LOG_BIN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:666
+msgid "Query execution was interrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:668
+#, c-format
+msgid "Incorrect number of arguments for %s %s; expected %u, got %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:670
+#, c-format
+msgid "Undefined CONDITION: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:672
+#, c-format
+msgid "No RETURN found in FUNCTION %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:674
+#, c-format
+msgid "FUNCTION %s ended without RETURN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:676
+msgid "Cursor statement must be a SELECT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:678
+msgid "Cursor SELECT must not have INTO"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:680
+#, c-format
+msgid "Undefined CURSOR: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:682
+msgid "Cursor is already open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:684
+msgid "Cursor is not open"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:686
+#, c-format
+msgid "Undeclared variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:688
+msgid "Incorrect number of FETCH variables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:690
+msgid "No data - zero rows fetched, selected, or processed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:692
+#, c-format
+msgid "Duplicate parameter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:694
+#, c-format
+msgid "Duplicate variable: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:696
+#, c-format
+msgid "Duplicate condition: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:698
+#, c-format
+msgid "Duplicate cursor: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:700
+#, c-format
+msgid "Failed to ALTER %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:702
+msgid "Subquery value not supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:704
+#, c-format
+msgid "%s is not allowed in stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:706
+msgid "Variable or condition declaration after cursor or handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:708
+msgid "Cursor declaration after handler declaration"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:710
+msgid "Case not found for CASE statement"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:712
+#, c-format
+msgid "Configuration file '%-.192s' is too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:714
+#, c-format
+msgid "Malformed file type header in file '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:716
+#, c-format
+msgid "Unexpected end of file while parsing comment '%-.200s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:718
+#, c-format
+msgid "Error while parsing parameter '%-.192s' (line: '%-.192s')"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:720
+#, c-format
+msgid "Unexpected end of file while skipping unknown parameter '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:722
+msgid "EXPLAIN/SHOW can not be issued; lacking privileges for underlying table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:724
+#, c-format
+msgid "File '%-.192s' has unknown type '%-.64s' in its header"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:726
+#, c-format
+msgid "'%-.192s.%-.192s' is not %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:728
+#, c-format
+msgid "Column '%-.192s' is not updatable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:730
+msgid "View's SELECT contains a subquery in the FROM clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:732
+#, c-format
+msgid "View's SELECT contains a '%s' clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:734
+msgid "View's SELECT contains a variable or parameter"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:736
+#, c-format
+msgid "View's SELECT refers to a temporary table '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:738
+msgid "View's SELECT and view's field list have different column counts"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:740
+msgid ""
+"View merge algorithm can't be used here for now (assumed undefined algorithm)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:742
+msgid "View being updated does not have complete key of underlying table in it"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:744
+#, c-format
+msgid ""
+"View '%-.192s.%-.192s' references invalid table(s) or column(s) or function"
+"(s) or definer/invoker of view lack rights to use them"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:746
+#, c-format
+msgid "Can't drop or alter a %s from within another stored routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:748
+msgid "GOTO is not allowed in a stored procedure handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:750
+msgid "Trigger already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:752
+msgid "Trigger does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:754
+#, c-format
+msgid "Trigger's '%-.192s' is view or temporary table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:756
+#, c-format
+msgid "Updating of %s row is not allowed in %strigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:758
+#, c-format
+msgid "There is no %s row in %s trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:760
+#, c-format
+msgid "Field '%-.192s' doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:762
+msgid "Division by 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:764
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for column '%.192s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:766
+#, c-format
+msgid "Illegal %s '%-.192s' value found during parsing"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:768
+#, c-format
+msgid "CHECK OPTION on non-updatable view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:770
+#, c-format
+msgid "CHECK OPTION failed '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:772
+#, c-format
+msgid "%-.16s command denied to user '%-.48s'@'%-.64s' for routine '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:774
+#, c-format
+msgid "Failed purging old relay logs: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:776
+#, c-format
+msgid "Password hash should be a %d-digit hexadecimal number"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:778
+msgid "Target log not found in binlog index"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:780
+msgid "I/O error reading log index file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:782
+msgid "Server configuration does not permit binlog purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:784
+msgid "Failed on fseek()"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:786
+msgid "Fatal error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:788
+msgid "A purgeable log is in use, will not purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:790
+msgid "Unknown error during log purge"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:792
+#, c-format
+msgid "Failed initializing relay log position: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:794
+msgid "You are not using binary logging"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:796
+#, c-format
+msgid ""
+"The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:798
+msgid "WSAStartup Failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:800
+msgid "Can't handle procedures with different groups yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:802
+msgid "Select must have a group with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:804
+msgid "Can't use ORDER clause with this procedure"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:806
+#, c-format
+msgid "Binary logging and replication forbid changing the global server %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:808
+#, c-format
+msgid "Can't map file: %-.200s, errno: %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:810
+#, c-format
+msgid "Wrong magic in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:812
+msgid "Prepared statement contains too many placeholders"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:814
+#, c-format
+msgid "Key part '%-.192s' length cannot be 0"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:816
+msgid "View text checksum failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:818
+#, c-format
+msgid ""
+"Can not modify more than one base table through a join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:820
+#, c-format
+msgid "Can not insert into join view '%-.192s.%-.192s' without fields list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:822
+#, c-format
+msgid "Can not delete from join view '%-.192s.%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:824
+#, c-format
+msgid "Operation %s failed for %.256s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:826
+msgid "XAER_NOTA: Unknown XID"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:828
+msgid "XAER_INVAL: Invalid arguments (or unsupported command)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:830
+#, c-format
+msgid ""
+"XAER_RMFAIL: The command cannot be executed when global transaction is in "
+"the  %.64s state"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:832
+msgid "XAER_OUTSIDE: Some work is done outside global transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:834
+msgid ""
+"XAER_RMERR: Fatal error occurred in the transaction branch - check your data "
+"for consistency"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:836
+msgid "XA_RBROLLBACK: Transaction branch was rolled back"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:838
+#, c-format
+msgid ""
+"There is no such grant defined for user '%-.48s' on host '%-.64s' on routine "
+"'%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:840
+msgid "Failed to grant EXECUTE and ALTER ROUTINE privileges"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:842
+msgid "Failed to revoke all privileges to dropped routine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:844
+#, c-format
+msgid "Data too long for column '%s' at row %ld"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:846
+#, c-format
+msgid "Bad SQLSTATE: '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:848
+#, c-format
+msgid ""
+"%s: ready for connections.\n"
+"Version: '%s'  socket: '%s'  port: %d  %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:850
+msgid "Can't load value from file with fixed size rows to variable"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:852
+msgid "You are not allowed to create a user with GRANT"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:854
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s' for function %-.32s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:856
+msgid "Table definition has changed, please retry transaction"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:858
+msgid "Duplicate handler declared in the same block"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:860
+#, c-format
+msgid ""
+"OUT or INOUT argument %d for routine %s is not a variable or NEW pseudo-"
+"variable in BEFORE trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:862
+#, c-format
+msgid "Not allowed to return a result set from a %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:864
+msgid "Cannot get geometry object from data you send to the GEOMETRY field"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:866
+msgid ""
+"A routine failed and has neither NO SQL nor READS SQL DATA in its "
+"declaration and binary logging is enabled; if non-transactional tables were "
+"updated, the binary log will miss their changes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:868
+msgid ""
+"This function has none of DETERMINISTIC, NO SQL, or READS SQL DATA in its "
+"declaration and binary logging is enabled (you *might* want to use the less "
+"safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:870
+msgid ""
+"You do not have the SUPER privilege and binary logging is enabled (you "
+"*might* want to use the less safe log_bin_trust_function_creators variable)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:872
+msgid ""
+"You can't execute a prepared statement which has an open cursor associated "
+"with it. Reset the statement to re-execute it."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:874
+#, c-format
+msgid "The statement (%lu) has no open cursor."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:876
+msgid ""
+"Explicit or implicit commit is not allowed in stored function or trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:878
+#, c-format
+msgid ""
+"Field of view '%-.192s.%-.192s' underlying table doesn't have a default value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:880
+msgid "Recursive stored functions and triggers are not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:882
+#, c-format
+msgid "Too big scale %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:884
+#, c-format
+msgid "Too big precision %d specified for column '%-.192s'. Maximum is %d."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:886
+#, c-format
+msgid ""
+"For float(M,D), double(M,D) or decimal(M,D), M must be >= D (column "
+"'%-.192s')."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:888
+msgid ""
+"You can't combine write-locking of system tables with other tables or lock "
+"types"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:890
+#, c-format
+msgid "Unable to connect to foreign data source: %.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:892
+#, c-format
+msgid ""
+"There was a problem processing the query on the foreign data source. Data "
+"source error: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:894
+#, c-format
+msgid ""
+"The foreign data source you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:896
+#, c-format
+msgid ""
+"Can't create federated table. The data source connection string '%-.64s' is "
+"not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:898
+#, c-format
+msgid "The data source connection string '%-.64s' is not in the correct format"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:900
+#, c-format
+msgid "Can't create federated table. Foreign data src error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:902
+msgid "Trigger in wrong schema"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:904
+#, c-format
+msgid ""
+"Thread stack overrun:  %ld bytes used of a %ld byte stack, and %ld bytes "
+"needed.  Use 'mysqld -O thread_stack=#' to specify a bigger stack."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:906
+#, c-format
+msgid "Routine body for '%-.100s' is too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:908
+msgid "Cannot drop default keycache"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:910
+#, c-format
+msgid "Display width out of range for column '%-.192s' (max = %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:912
+msgid "XAER_DUPID: The XID already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:914
+#, c-format
+msgid "Datetime function: %-.32s field overflow"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:916
+#, c-format
+msgid ""
+"Can't update table '%-.192s' in stored function/trigger because it is "
+"already used by statement which invoked this stored function/trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:918
+#, c-format
+msgid ""
+"The definition of table '%-.192s' prevents operation %.192s on table "
+"'%-.192s'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:920
+msgid ""
+"The prepared statement contains a stored routine call that refers to that "
+"same statement. It's not allowed to execute a prepared statement in such a "
+"recursive manner"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:922
+msgid "Not allowed to set autocommit from a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:924
+msgid "Definer is not fully qualified"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:926
+#, c-format
+msgid ""
+"View '%-.192s'.'%-.192s' has no definer information (old table format). "
+"Current user is used as definer. Please recreate the view!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:928
+#, c-format
+msgid ""
+"You need the SUPER privilege for creation view with '%-.192s'@'%-.192s' "
+"definer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:930
+#, c-format
+msgid "The user specified as a definer ('%-.64s'@'%-.64s') does not exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:932
+#, c-format
+msgid "Changing schema from '%-.192s' to '%-.192s' is not allowed."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:934
+#, c-format
+msgid ""
+"Cannot delete or update a parent row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:936
+#, c-format
+msgid ""
+"Cannot add or update a child row: a foreign key constraint fails (%.192s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:938
+#, c-format
+msgid "Variable '%-.64s' must be quoted with `...`, or renamed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:940
+#, c-format
+msgid ""
+"No definer attribute for trigger '%-.192s'.'%-.192s'. The trigger will be "
+"activated under the authorization of the invoker, which may have "
+"insufficient privileges. Please recreate the trigger."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:942
+#, c-format
+msgid "'%-.192s' has an old format, you should re-create the '%s' object(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:944
+#, c-format
+msgid ""
+"Recursive limit %d (as set by the max_sp_recursion_depth variable) was "
+"exceeded for routine %.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:946
+#, c-format
+msgid ""
+"Failed to load routine %-.192s. The table mysql.proc is missing, corrupt, or "
+"contains bad data (internal code %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:948
+#, c-format
+msgid "Incorrect routine name '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:950
+#, c-format
+msgid "Table upgrade required. Please do \"REPAIR TABLE `%-.32s`\" to fix it!"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:952
+msgid "AGGREGATE is not supported for stored functions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:954
+#, c-format
+msgid ""
+"Can't create more than max_prepared_stmt_count statements (current value: %"
+"lu)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:956
+#, c-format
+msgid "`%-.192s`.`%-.192s` contains view recursion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:958
+#, c-format
+msgid "non-grouping field '%-.192s' is used in %-.64s clause"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:960
+msgid "The used table type doesn't support SPATIAL indexes"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:962
+msgid "Triggers can not be created on system tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:964
+#, c-format
+msgid "Leading spaces are removed from name '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:966
+msgid "Failed to read auto-increment value from storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:968
+msgid "user name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:970
+msgid "host name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:972
+#, c-format
+msgid "String '%-.70s' is too long for %s (should be no longer than %d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:974
+#, c-format
+msgid "The target table %-.100s of the %s is not insertable-into"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:976
+#, c-format
+msgid ""
+"Table '%-.64s' is differently defined or of non-MyISAM type or doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:978
+msgid "Too high level of nesting for select"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:980
+#, c-format
+msgid "Name '%-.64s' has become ''"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:982
+msgid ""
+"First character of the FIELDS TERMINATED string is ambiguous; please use non-"
+"optional and non-empty FIELDS ENCLOSED BY"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:984
+#, c-format
+msgid "The foreign server, %s, you are trying to create already exists."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:986
+#, c-format
+msgid ""
+"The foreign server name you are trying to reference does not exist. Data "
+"source error:  %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:988
+#, c-format
+msgid ""
+"Table storage engine '%-.64s' does not support the create option '%.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:990
+#, c-format
+msgid ""
+"Syntax error: %-.64s PARTITIONING requires definition of VALUES %-.64s for "
+"each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:992
+#, c-format
+msgid "Only %-.64s PARTITIONING can use VALUES %-.64s in partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:994
+msgid "MAXVALUE can only be used in last partition definition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:996
+msgid "Subpartitions can only be hash partitions and by key"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:998
+msgid "Must define subpartitions on all partitions if on one partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1000
+msgid "Wrong number of partitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1002
+msgid "Wrong number of subpartitions defined, mismatch with previous setting"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1004
+msgid "Constant/Random expression in (sub)partitioning function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1006
+msgid "Expression in RANGE/LIST VALUES must be constant"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1008
+msgid "Field in list of fields for partition function not found in table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1010
+msgid "List of fields is only allowed in KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1012
+msgid ""
+"The partition info in the frm file is not consistent with what can be "
+"written into the frm file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1014
+#, c-format
+msgid "The %-.192s function returns the wrong type"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1016
+#, c-format
+msgid "For %-.64s partitions each partition must be defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1018
+msgid "VALUES LESS THAN value must be strictly increasing for each partition"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1020
+msgid "VALUES value must be of same type as partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1022
+msgid "Multiple definition of same constant in list partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1024
+msgid "Partitioning can not be used stand-alone in query"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1026
+msgid ""
+"The mix of handlers in the partitions is not allowed in this version of MySQL"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1028
+#, c-format
+msgid "For the partitioned engine it is necessary to define all %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1030
+msgid "Too many partitions (including subpartitions) were defined"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1032
+msgid ""
+"It is only possible to mix RANGE/LIST partitioning with HASH/KEY "
+"partitioning for subpartitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1034
+msgid "Failed to create specific handler file"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1036
+msgid "A BLOB field is not allowed in partition function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1038
+#, c-format
+msgid "A %-.192s must include all columns in the table's partitioning function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1040
+#, c-format
+msgid "Number of %-.64s = 0 is not an allowed value"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1042
+msgid "Partition management on a not partitioned table is not possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1044
+msgid ""
+"Foreign key condition is not yet supported in conjunction with partitioning"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1046
+#, c-format
+msgid "Error in list of partitions to %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1048
+msgid "Cannot remove all partitions, use DROP TABLE instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1050
+msgid "COALESCE PARTITION can only be used on HASH/KEY partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1052
+msgid ""
+"REORGANISE PARTITION can only be used to reorganise partitions not to change "
+"their numbers"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1054
+msgid ""
+"REORGANISE PARTITION without parameters can only be used on auto-partitioned "
+"tables using HASH PARTITIONs"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1056
+#, c-format
+msgid "%-.64s PARTITION can only be used on RANGE/LIST partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1058
+msgid "Trying to Add partition(s) with wrong number of subpartitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1060
+msgid "At least one partition must be added"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1062
+msgid "At least one partition must be coalesced"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1064
+msgid "More partitions to reorganise than there are partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1066
+#, c-format
+msgid "Duplicate partition name %-.192s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1068
+msgid "It is not allowed to shut off binlog on this command"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1070
+msgid "When reorganising a set of partitions they must be in consecutive order"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1072
+msgid ""
+"Reorganize of range partitions cannot change total ranges except for last "
+"partition where it can extend the range"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1074
+msgid "Partition function not supported in this version for this handler"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1076
+msgid "Partition state cannot be defined from CREATE/ALTER TABLE"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1078
+#, c-format
+msgid "The %-.64s handler only supports 32 bit integers in VALUES"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1080
+#, c-format
+msgid "Plugin '%-.192s' is not loaded"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1082
+#, c-format
+msgid "Incorrect %-.32s value: '%-.128s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1084
+#, c-format
+msgid "Table has no partition for value %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1086
+#, c-format
+msgid "It is not allowed to specify %s more than once"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1088
+#: drizzled/drizzled_error_messages.h:1224
+#, c-format
+msgid "Failed to create %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1090
+#: drizzled/drizzled_error_messages.h:1114
+#, c-format
+msgid "Failed to drop %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1092
+msgid "The handler doesn't support autoextend of tablespaces"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1094
+msgid ""
+"A size parameter was incorrectly specified, either number or on the form 10M"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1096
+msgid ""
+"The size number was correct but we don't allow the digit part to be more "
+"than 2 billion"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1098
+#, c-format
+msgid "Failed to alter: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1100
+msgid "Writing one row to the row-based binary log failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1102
+#, c-format
+msgid "Table definition on master and slave does not match: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1104
+msgid ""
+"Slave running with --log-slave-updates must use row-based binary logging to "
+"be able to replicate row-based binary log events"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1106
+#, c-format
+msgid "Event '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1108
+#, c-format
+msgid "Failed to store event %s. Error code %d from storage engine."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1110
+#, c-format
+msgid "Unknown event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1112
+#, c-format
+msgid "Failed to alter event '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1116
+msgid "INTERVAL is either not positive or too big"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1118
+msgid "ENDS is either invalid or before STARTS"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1120
+msgid "Event execution time is in the past. Event has been disabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1122
+msgid "Failed to open mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1124
+msgid "No datetime expression provided"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1126
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. The table is "
+"probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1128
+#, c-format
+msgid "Cannot load from mysql.%s. The table is probably corrupted"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1130
+msgid "Failed to delete the event from mysql.event"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1132
+msgid "Error during compilation of event's body"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1134
+msgid "Same old and new event name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1136
+#, c-format
+msgid "Data for column '%s' too long"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1138
+#, c-format
+msgid "Cannot drop index '%-.192s': needed in a foreign key constraint"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1140
+#, c-format
+msgid ""
+"The syntax '%s' is deprecated and will be removed in MySQL %s. Please use %s "
+"instead"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1142
+msgid "You can't write-lock a log table. Only read access is possible"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1144
+msgid "You can't use locks with log tables."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1146
+#, c-format
+msgid ""
+"Upholding foreign key constraints for table '%.192s', entry '%-.192s', key %"
+"d would lead to a duplicate entry"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1148
+#, c-format
+msgid ""
+"Column count of mysql.%s is wrong. Expected %d, found %d. Created with MySQL "
+"%d, now running %d. Please use mysql_upgrade to fix this error."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1150
+msgid ""
+"Cannot switch out of the row-based binary log format when the session has "
+"open temporary tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1152
+msgid ""
+"Cannot change the binary logging format inside a stored function or trigger"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1154
+msgid ""
+"The NDB cluster engine does not support changing the binlog format on the "
+"fly yet"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1156
+msgid "Cannot create temporary table with partitions"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1158
+msgid "Partition constant is out of partition function domain"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1160
+msgid "This partition function is not allowed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1162
+msgid "Error in DDL log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1164
+msgid "Not allowed to use NULL value in VALUES LESS THAN"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1166
+msgid "Incorrect partition name"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1168
+msgid ""
+"Transaction isolation level can't be changed while a transaction is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1170
+#, c-format
+msgid ""
+"ALTER TABLE causes auto_increment resequencing, resulting in duplicate entry "
+"'%-.192s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1172
+#, c-format
+msgid "Internal scheduler error %d"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1174
+#, c-format
+msgid "Error during starting/stopping of the scheduler. Error code %u"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1176
+msgid "Engine cannot be used in partitioned tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1178
+#, c-format
+msgid "Cannot activate '%-.64s' log"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1180
+msgid "The server was not built with row-based replication"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1182
+msgid "Decoding of base64 string failed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1184
+msgid "Recursion of EVENT DDL statements is forbidden when body is present"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1186
+msgid ""
+"Cannot proceed because system tables used by Event Scheduler were found "
+"damaged at server start"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1188
+msgid "Only integers allowed as number here"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1190
+msgid "This storage engine cannot be used for log tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1192
+#, c-format
+msgid "You cannot '%s' a log table if logging is enabled"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1194
+#, c-format
+msgid ""
+"Cannot rename '%s'. When logging enabled, rename to/from log table must "
+"rename two tables: the log table to an archive table and another table back "
+"to '%s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1196
+#, c-format
+msgid "Incorrect parameter count in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1198
+#, c-format
+msgid "Incorrect parameters in the call to native function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1200
+#, c-format
+msgid "Incorrect parameters in the call to stored function '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1202
+#, c-format
+msgid "This function '%-.192s' has the same name as a native function"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1204
+#, c-format
+msgid "Duplicate entry '%-.64s' for key '%-.192s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1206
+msgid "Too many files opened, please execute the command again"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1208
+#: drizzled/drizzled_error_messages.h:1210
+msgid ""
+"Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. "
+"The event was dropped immediately after creation."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1212
+#, c-format
+msgid "The incident %s occured on the master. Message: %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1214
+msgid "Table has no partition for some existing values"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1216
+msgid "Statement is not safe to log in statement format."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1218
+#, c-format
+msgid "Fatal error: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1220
+#, c-format
+msgid "Relay log read failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1222
+#, c-format
+msgid "Relay log write failure: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1226
+#, c-format
+msgid "Master command %s failed: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1228
+#, c-format
+msgid "Binary logging not possible. Message: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1230
+#, c-format
+msgid "View `%-.64s`.`%-.64s` has no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1232
+#, c-format
+msgid "Creation context of view `%-.64s`.`%-.64s' is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1234
+#, c-format
+msgid "Creation context of stored routine `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1236
+#, c-format
+msgid "Corrupted TRG file for table `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1238
+#, c-format
+msgid "Triggers for table `%-.64s`.`%-.64s` have no creation context"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1240
+#, c-format
+msgid "Trigger creation context of table `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1242
+#, c-format
+msgid "Creation context of event `%-.64s`.`%-.64s` is invalid"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1244
+#, c-format
+msgid "Cannot open table for trigger `%-.64s`.`%-.64s`"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1246
+#, c-format
+msgid "Cannot create stored routine `%-.64s`. Check warnings"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1248
+#, c-format
+msgid "Ambiguous slave modes combination. %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1250
+#, c-format
+msgid ""
+"The BINLOG statement of type `%s` was not preceded by a format description "
+"BINLOG statement."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1252
+msgid "Corrupted replication event was detected"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1254
+#, c-format
+msgid "Invalid column reference (%-.64s) in LOAD DATA"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1256
+#, c-format
+msgid "Being purged log %s was not found"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1258
+#, c-format
+msgid "Converted to non-transactional lock on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1260
+#, c-format
+msgid "Cannot convert to non-transactional lock in strict mode on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1262
+#, c-format
+msgid ""
+"Cannot convert to non-transactional lock in an active transaction on '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1264
+#, c-format
+msgid "Can't access storage engine of table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1266
+msgid "Starting backup process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1268
+msgid "Backup completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1270
+msgid "Starting restore process"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1272
+msgid "Restore completed"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1274
+msgid "Nothing to backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1276
+#, c-format
+msgid "Database '%-.64s' cannot be included in a backup"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1278
+msgid ""
+"Error during backup operation - server's error log contains more information "
+"about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1280
+msgid ""
+"Error during restore operation - server's error log contains more "
+"information about the error"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1282
+msgid ""
+"Can't execute this command because another BACKUP/RESTORE operation is in "
+"progress"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1284
+msgid "Error when preparing for backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1286
+msgid "Error when preparing for restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1288
+#, c-format
+msgid "Invalid backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1290
+#, c-format
+msgid "Can't read backup location '%-.64s'"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1292
+#, c-format
+msgid "Can't write to backup location '%-.64s' (file already exists?)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1294
+msgid "Can't enumerate server databases"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1296
+msgid "Can't enumerate server tables"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1298
+#, c-format
+msgid "Can't enumerate tables in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1300
+#, c-format
+msgid "Skipping view %-.64s in database %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1302
+#, c-format
+msgid "Skipping table %-.64s since it has no valid storage engine"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1304
+#, c-format
+msgid "Can't open table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1306
+msgid "Can't read backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1308
+msgid "Can't write backup archive preamble"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1310
+#, c-format
+msgid "Can't find backup driver for table %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1312
+#, c-format
+msgid ""
+"%-.64s backup driver was selected for table %-.64s but it rejects to handle "
+"this table"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1314
+#, c-format
+msgid "Can't create %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1316
+#, c-format
+msgid "Can't create %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1318
+#, c-format
+msgid "Found %d images in backup archive but maximum %d are supported"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1320
+#, c-format
+msgid "Error when saving meta-data of %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1322
+msgid "Error when reading meta-data list"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1324
+#, c-format
+msgid "Can't create %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1326
+msgid "Can't allocate buffer for image data transfer"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1328
+#, c-format
+msgid "Error when writing %-.64s backup image data (for table #%d)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1330
+msgid "Error when reading data from backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1332
+msgid "Can't go to the next chunk in backup stream"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1334
+#, c-format
+msgid "Can't initialize %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1336
+#, c-format
+msgid "Can't initialize %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1338
+#, c-format
+msgid "Can't shut down %-.64s backup driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1340
+#, c-format
+msgid "Can't shut down %-.64s backup driver(s)"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1342
+#, c-format
+msgid "%-.64s backup driver can't prepare for synchronization"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1344
+#, c-format
+msgid "%-.64s backup driver can't create its image validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1346
+#, c-format
+msgid "Can't unlock %-.64s backup driver after creating the validity point"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1348
+#, c-format
+msgid "%-.64s backup driver can't cancel its backup operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1350
+#, c-format
+msgid "%-.64s restore driver can't cancel its restore operation"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1352
+#, c-format
+msgid "Error when polling %-.64s backup driver for its image data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1354
+#, c-format
+msgid "Error when sending image data (for table #%d) to %-.64s restore driver"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1356
+#, c-format
+msgid ""
+"After %d attempts %-.64s restore driver still can't accept next block of data"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1358
+#, c-format
+msgid "Open and lock tables failed in %-.64s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1360
+msgid "Backup driver's table locking thread can not be initialized."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1362
+msgid ""
+"Can't open the online backup progress tables. Check 'mysql.online_backup' "
+"and 'mysql.online_backup_progress'."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1364
+#, c-format
+msgid "Tablespace '%-.192s' already exists"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1366
+#, c-format
+msgid "Tablespace '%-.192s' doesn't exist"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1368
+#, c-format
+msgid "Unexpected master's heartbeat data: %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1370
+#, c-format
+msgid "The requested value for the heartbeat period %s %s"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1372
+#, c-format
+msgid "Can't write to the online backup progress log %-.64s."
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1374
+#, c-format
+msgid "Tablespace '%-.192s' not empty"
+msgstr ""
+
+#: drizzled/drizzled_error_messages.h:1376
+#, c-format
+msgid ""
+"Tablespace `%-.64s` needed by tables being restored has changed on the "
+"server. The original definition of the required tablespace is '%-.256s' "
+"while the same tablespace is defined on the server as '%-.256s'"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -1291,8 +4598,7 @@
 
 #: drizzled/slave.cc:102
 #, c-format
-msgid ""
-"failed dump request, reconnecting to try again, log '%s' at postion %s"
+msgid "failed dump request, reconnecting to try again, log '%s' at postion %s"
 msgstr ""
 
 #: drizzled/slave.cc:108
@@ -1300,8 +4606,7 @@
 msgstr ""
 
 #: drizzled/slave.cc:109
-msgid ""
-"Slave I/O thread killed while waiting to reconnect after a failed read"
+msgid "Slave I/O thread killed while waiting to reconnect after a failed read"
 msgstr ""
 
 #: drizzled/slave.cc:111
@@ -1525,8 +4830,8 @@
 #: drizzled/slave.cc:2337
 #, c-format
 msgid ""
-"Slave SQL thread initialized, starting replication in log '%s' at position "
-"%s, relay log '%s' position: %s"
+"Slave SQL thread initialized, starting replication in log '%s' at position %"
+"s, relay log '%s' position: %s"
 msgstr ""
 
 #: drizzled/slave.cc:2351

=== modified file 'storage/archive/Makefile.am'
--- storage/archive/Makefile.am	2008-08-09 02:24:34 +0000
+++ storage/archive/Makefile.am	2008-08-12 03:53:33 +0000
@@ -23,9 +23,8 @@
 pkgplugindir =		$(pkglibdir)/plugin
 
 LDADD = $(LIBINTL)
-AM_CFLAGS = -DHAVE_MYSQL_CONFIG_H
 
-DEFS =                  @DEFS@
+DEFS =                  @DEFS@ -DHAVE_MYSQL_CONFIG_H
 
 noinst_HEADERS =	ha_archive.h azio.h
 noinst_PROGRAMS	=	archive_test archive_reader archive_performance concurrency_test
@@ -33,14 +32,14 @@
 EXTRA_LTLIBRARIES =	ha_archive.la
 pkglib_LTLIBRARIES =	@plugin_archive_shared_target@
 ha_archive_la_LDFLAGS =	-module -rpath $(pkgplugindir) $(LDADD)
-ha_archive_la_CXXFLAGS=	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
-ha_archive_la_CFLAGS =	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
+ha_archive_la_CXXFLAGS=	$(AM_CXXFLAGS) -DMYSQL_DYNAMIC_PLUGIN
+ha_archive_la_CFLAGS =	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN 
 ha_archive_la_SOURCES =	ha_archive.cc azio.c
 
 
 EXTRA_LIBRARIES =	libarchive.a
 noinst_LIBRARIES =	@plugin_archive_static_target@
-libarchive_a_CXXFLAGS =	$(AM_CFLAGS) 
+libarchive_a_CXXFLAGS =	$(AM_CXXFLAGS) 
 libarchive_a_CFLAGS =	$(AM_CFLAGS) 
 libarchive_a_SOURCES =	ha_archive.cc azio.c
 

=== modified file 'storage/blackhole/Makefile.am'
--- storage/blackhole/Makefile.am	2008-07-30 19:17:49 +0000
+++ storage/blackhole/Makefile.am	2008-08-12 01:11:07 +0000
@@ -30,15 +30,12 @@
 EXTRA_LTLIBRARIES =	ha_blackhole.la
 pkgplugin_LTLIBRARIES =	@plugin_blackhole_shared_target@
 ha_blackhole_la_LDFLAGS=-module -rpath $(pkgplugindir)
-ha_blackhole_la_CXXFLAGS=$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
-ha_blackhole_la_CFLAGS=	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
+ha_blackhole_la_CXXFLAGS=$(AM_CXXFLAGS) -DMYSQL_DYNAMIC_PLUGIN
 ha_blackhole_la_SOURCES=ha_blackhole.cc
 
 
 EXTRA_LIBRARIES =	libblackhole.a
 noinst_LIBRARIES =	@plugin_blackhole_static_target@
-libblackhole_a_CXXFLAGS=$(AM_CFLAGS)
-libblackhole_a_CFLAGS =	$(AM_CFLAGS)
 libblackhole_a_SOURCES=	ha_blackhole.cc
 
 

=== modified file 'storage/csv/Makefile.am'
--- storage/csv/Makefile.am	2008-07-30 19:17:49 +0000
+++ storage/csv/Makefile.am	2008-08-12 01:11:07 +0000
@@ -26,12 +26,11 @@
 EXTRA_LTLIBRARIES =	ha_csv.la
 pkglib_LTLIBRARIES =	@plugin_csv_shared_target@
 ha_csv_la_LDFLAGS =	-module -rpath $(MYSQLLIBdir)
-ha_csv_la_CXXFLAGS =	$(AM_CFLAGS) -DMYSQL_PLUGIN
+ha_csv_la_CXXFLAGS =	$(AM_CXXFLAGS) -DMYSQL_PLUGIN
 ha_csv_la_SOURCES =	transparent_file.cc ha_tina.cc 
 
 EXTRA_LIBRARIES =	libcsv.a
 noinst_LIBRARIES =	@plugin_csv_static_target@
-libcsv_a_CXXFLAGS =	$(AM_CFLAGS)
 libcsv_a_SOURCES =	transparent_file.cc ha_tina.cc
 
 EXTRA_DIST =		plug.in

=== modified file 'storage/innobase/Makefile.am'
--- storage/innobase/Makefile.am	2008-07-30 19:17:49 +0000
+++ storage/innobase/Makefile.am	2008-08-12 01:11:07 +0000
@@ -152,14 +152,11 @@
 			ut/ut0ut.c ut/ut0vec.c ut/ut0wqueue.c		\
 			handler/ha_innodb.cc
 
-libinnobase_a_CXXFLAGS=	$(AM_CFLAGS)
-libinnobase_a_CFLAGS  =	$(AM_CFLAGS)
-
 EXTRA_LTLIBRARIES =	ha_innodb.la
 pkglib_LTLIBRARIES =	@plugin_innobase_shared_target@
 
 ha_innodb_la_LDFLAGS =	-module -rpath $(pkgplugindir)
-ha_innodb_la_CXXFLAGS=	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
+ha_innodb_la_CXXFLAGS=	$(AM_CXXFLAGS) -DMYSQL_DYNAMIC_PLUGIN
 ha_innodb_la_CFLAGS  =	$(AM_CFLAGS) -DMYSQL_DYNAMIC_PLUGIN
 ha_innodb_la_SOURCES =	$(libinnobase_a_SOURCES)
 

